<?php

///////////////////////////////////////
// sanitize.inc.php
// Sanitization functions for PHP
// by: Gavin Zuchlinski, Jamie Pratt, Hokkaido
// webpage: http://libox.net
// Last modified: September 27, 2003
//
// Many thanks to those on the webappsec list for helping me improve these functions
///////////////////////////////////////
// Function list:
// sanitize_paranoid_string($string) -- input string, returns string stripped of all non 
//           alphanumeric
// sanitize_system_string($string) -- input string, returns string stripped of special
//           characters
// sanitize_sql_string($string) -- input string, returns string with slashed out quotes
// sanitize_html_string($string) -- input string, returns string with html replacements
//           for special characters
// sanitize_int($integer) -- input integer, returns ONLY the integer (no extraneous 
//           characters
// sanitize_float($float) -- input float, returns ONLY the float (no extraneous 
//           characters)
// sanitize($input, $flags) -- input any variable, performs sanitization 
//           functions specified in flags. flags can be bitwise 
//           combination of PARANOID, SQL, SYSTEM, HTML, INT, FLOAT, LDAP, 
//           UTF8
///////////////////////////////////////
define("PARANOID", 1);
define("SQL", 2);
define("SYSTEM", 4);
define("HTML", 8);
define("INT", 16);
define("FLOAT", 32);
define("LDAP", 64);
define("UTF8", 128);

// internal function for utf8 decoding
// thanks to Jamie Pratt for noticing that PHP's function is a little 
// screwy

function my_utf8_decode($string)
{
return strtr($string, 
  "???????", 
  "SOZsozYYuAAAAAAACEEEEIIIIDNOOOOOOUUUUYsaaaaaaaceeeeiiiionoooooouuuuyy");
}

// paranoid sanitization -- only let the alphanumeric set through
function sanitize_paranoid_string($string, $min='', $max='')
{
  $string = preg_replace("/[^a-zA-Z0-9]/", "", $string);
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
    return FALSE;
  return $string;
}

// sanitize a string in prep for passing a single argument to system() (or similar)
function sanitize_system_string($string, $min='', $max='')
{
  $pattern = '/(;|\||`|>|<|&|^|"|'."\n|\r|'".'|{|}|[|]|\)|\()/i'; // no piping, passing possible environment variables ($),
                           // seperate commands, nested execution, file redirection, 
                           // background processing, special commands (backspace, etc.), quotes
                           // newlines, or some other special characters
  $string = preg_replace($pattern, '', $string);
  $string = '"'.preg_replace('/\$/', '\\\$', $string).'"'; //make sure this is only interpretted as ONE argument
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
    return FALSE;
  return $string;
}

// sanitize a string for SQL input (simple slash out quotes and slashes)
function sanitize_sql_string($string, $min='', $max='')
{
  $pattern[0] = '/(\\\\)/';
  $pattern[1] = "/\"/";
  $pattern[2] = "/'/";
  $replacement[0] = '\\\\\\';
  $replacement[1] = '\"';
  $replacement[2] = "\\'";
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
    return FALSE;
  return preg_replace($pattern, $replacement, $string);
}

// sanitize a string for SQL input (simple slash out quotes and slashes)
function sanitize_ldap_string($string, $min='', $max='')
{
  $pattern = '/(\)|\(|\||&)/';
  $len = strlen($string);
  if((($min != '') && ($len < $min)) || (($max != '') && ($len > $max)))
    return FALSE;
  return preg_replace($pattern, '', $string);
}


// sanitize a string for HTML (make sure nothing gets interpretted!)
function sanitize_html_string($string)
{
  $pattern[0] = '/\&/';
  $pattern[1] = '/</';
  $pattern[2] = "/>/";
  $pattern[3] = '/\n/';
  $pattern[4] = '/"/';
  $pattern[5] = "/'/";
  $pattern[6] = "/%/";
  $pattern[7] = '/\(/';
  $pattern[8] = '/\)/';
  $pattern[9] = '/\+/';
  $pattern[10] = '/-/';
  $replacement[0] = '&amp;';
  $replacement[1] = '&lt;';
  $replacement[2] = '&gt;';
  $replacement[3] = '<br>';
  $replacement[4] = '&quot;';
  $replacement[5] = '&#39;';
  $replacement[6] = '&#37;';
  $replacement[7] = '&#40;';
  $replacement[8] = '&#41;';
  $replacement[9] = '&#43;';
  $replacement[10] = '&#45;';
  return preg_replace($pattern, $replacement, $string);
}

// make int int!
function sanitize_int($integer, $min='', $max='')
{
  $int = intval($integer);
  if((($min != '') && ($int < $min)) || (($max != '') && ($int > $max)))
    return FALSE;
  return $int;
}

// make float float!
function sanitize_float($float, $min='', $max='')
{
  $float = floatval($float);
  if((($min != '') && ($float < $min)) || (($max != '') && ($float > $max)))
    return FALSE;
  return $float;
}

// glue together all the other functions
function sanitize($input, $flags, $min='', $max='')
{
  if($flags & UTF8) $input = my_utf8_decode($input);
  if($flags & PARANOID) $input = sanitize_paranoid_string($input, $min, $max);
  if($flags & INT) $input = sanitize_int($input, $min, $max);
  if($flags & FLOAT) $input = sanitize_float($input, $min, $max);
  if($flags & HTML) $input = sanitize_html_string($input, $min, $max);
  if($flags & SQL) $input = sanitize_sql_string($input, $min, $max);
  if($flags & LDAP) $input = sanitize_ldap_string($input, $min, $max);
  if($flags & SYSTEM) $input = sanitize_system_string($input, $min, $max);
  return $input;
}

// end of sanitize
	function preview_text($TEXT, $LIMIT, $TAGS = 0) {
	
		// TRIM TEXT
		$TEXT = trim($TEXT);
	
		// STRIP TAGS IF PREVIEW IS WITHOUT HTML
		if ($TAGS == 0) $TEXT = preg_replace('/\s\s+/', ' ', strip_tags($TEXT));
	
		// IF STRLEN IS SMALLER THAN LIMIT RETURN
		if (strlen($TEXT) < $LIMIT) return $TEXT;
	
		if ($TAGS == 0) return substr($TEXT, 0, $LIMIT) . " ...";
		else {
	
			$COUNTER = 0;
			for ($i = 0; $i<= strlen($TEXT); $i++) {
	
				if ($TEXT{$i} == "<") $STOP = 1;
	
				if ($STOP != 1) {
	
					$COUNTER++;
				}
	
				if ($TEXT{$i} == ">") $STOP = 0;
				$RETURN .= $TEXT{$i};
	
				if ($COUNTER >= $LIMIT && $TEXT{$i} == " ") break;
	
			}
	
			return $RETURN . "...";
		}
	}	
	function ProperCase($strToConvert)
	{
		$strToReturn = ucwords(strtolower($strToConvert));
		return $strToReturn;
	
	} 
	function getCountryListForCombo($GCountry='')
	{
		
		$testclass		=	new AllTables();
		$countrylist 	=	$testclass->getInfo('', "SELECT * from mstcountry");
		
		$rowcount = count($countrylist);
		
		$strCountryList = "";
		
		if ($rowcount > 0)
		{
			$currentcountry = strtolower(rtrim(ltrim($GCountry)));
			for($i=0;$i<$rowcount;$i++) 	
			{	
				$databasecountry = strtolower(rtrim(ltrim($countrylist[$i]['countryname'])));
				$compare = strcmp($currentcountry,$databasecountry);
				
				if ($compare == 0)
				{
					$strCountryList .= "<option value='".$countrylist[$i]['countryid']."-".$countrylist[$i]['countryname']."' selected='selected'>".ucwords(strtolower($countrylist[$i]['countryname']))."</option>";
				}
				else
				{	
					$strCountryList .= "<option value='".$countrylist[$i]['countryid']."-".$countrylist[$i]['countryname']."'>".ucwords(strtolower($countrylist[$i]['countryname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strCountryList;	
	}
	
	function getCityListForCombo($GCity='',$countryid='',$countryname='')
	{
		$testclass		=	new AllTables();
		
		if ($countryid!='')
		{
			$citylist = $testclass->getInfo("","SELECT cityid,cityname,citycode FROM mstcity WHERE countryid ='".$countryid."' ORDER BY cityorder DESC , cityname, cityid");
		}
		else if($countryname!='')
		{
			$citylist = $testclass->getInfo("","SELECT cityid,cityname,citycode FROM mstcity WHERE countryid in (Select countryid from mstcountry where countryname ='".$countryname."') ORDER BY cityorder DESC , cityname, cityid");
		}
		else
		{
			$citylist = $testclass->getInfo("","select cityid,cityname,citycode from mstcity ORDER BY cityorder DESC , cityname, cityid");
		}
		$rowcount = count($citylist);
		
		$strCityList = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($GCity)==$citylist[$i]['cityname'])
				{
					$strCityList .= "<option value='".$citylist[$i]['cityid']."-".$citylist[$i]['cityname']."' selected='selected'>".ucwords(strtolower($citylist[$i]['cityname']))."</option>";
				}
				else
				{	
					$strCityList .= "<option value='".$citylist[$i]['cityid']."-".$citylist[$i]['cityname']."'>".ucwords(strtolower($citylist[$i]['cityname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strCityList;	
	}
	
	function getStateListForCombo($GStateid='',$countryid='',$countryname='')
	{
		$testclass		=	new AllTables();
		
		if ($countryid!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid ='".$countryid."' ORDER BY State asc");
		}
		else if($countryname!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid in (Select countryid from mstcountry where countryname ='".$countryname."') ORDER BY State");
		}
		else
		{
			$statelist = $testclass->getInfo("","select * FROM mststate ORDER BY State");
		}
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($GStateid)==$statelist[$i]['State'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['StateId']."-".$statelist[$i]['State']."' selected='selected'>".ucwords(strtolower($statelist[$i]['State']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['StateId']."-".$statelist[$i]['State']."'>".ucwords(strtolower($statelist[$i]['State']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	
	
	
	function getRegionsListForCombo($GRegion='')
	{
		
				$testclass		=	new AllTables();
				$regionlist 	=	$testclass->getInfo('', "SELECT * from mstregion order by regionname asc");
				
				$rowcount = count($regionlist);
				
				$strregionlist = "";
				
				if ($rowcount > 0)
				{
					$currentregion = strtolower(rtrim(ltrim($GRegion)));
					for($i=0;$i<$rowcount;$i++) 	
					{	
						$databaseregion = strtolower(rtrim(ltrim($regionlist[$i]['regionname'])));
						$compare = strcmp($currentregion,$databaseregion);
						
						if ($compare == 0)
						{
							$strregionlist .= "<option value='".$regionlist[$i]['regionid']."-".$regionlist[$i]['regionname']."' selected='selected'>".ucwords(strtolower($regionlist[$i]['regionname']))."</option>";
						}
						else
						{	
							$strregionlist .= "<option value='".$regionlist[$i]['regionid']."-".$regionlist[$i]['regionname']."'>".ucwords(strtolower($regionlist[$i]['regionname']))."</option>";
						}
					}
				}
				unset($testclass);
				return $strregionlist;	
	}
	function getPagesListForCombo($Gpages='')
	{
		
				$testclass		=	new AllTables();
				$pageslist 	=	$testclass->getInfo('', "SELECT * from mstpages ");
				
				$rowcount = count($pageslist);
				
				$strpageslist = "";
				
				if ($rowcount > 0)
				{
					$currentpages = strtolower(rtrim(ltrim($Gpages)));
					for($i=0;$i<$rowcount;$i++) 	
					{	
						$databasepages = strtolower(rtrim(ltrim($pageslist[$i]['pagename'])));
						$compare = strcmp($currentpages,$databasepages);
						
						if ($compare == 0)
						{
							$strpageslist .= "<option value='".$pageslist[$i]['pageid']."' selected='selected'>".ucwords(strtolower($pageslist[$i]['pagename']))."</option>";
						}
						else
						{	
							$strpageslist .= "<option value='".$pageslist[$i]['pageid']."'>".ucwords(strtolower($pageslist[$i]['pagename']))."</option>";
						}
					}
				}
				unset($testclass);
				return $strpageslist;	
	}
	function getThemeListForCombo($GTheme='')
	{
		
				$testclass		=	new AllTables();
				$themelist 	=	$testclass->getInfo('', "SELECT * from msttheme order by themename asc");
				
				$rowcount = count($themelist);
				
				$strTheme = "";
				
				if ($rowcount > 0)
				{
					$currenttheme = strtolower(rtrim(ltrim($GTheme)));
					for($i=0;$i<$rowcount;$i++) 	
					{	
						$databasetheme = strtolower(rtrim(ltrim($themelist[$i]['themename'])));
						$compare = strcmp($currenttheme,$databasetheme);
						
						if ($compare == 0)
						{
							$strTheme .= "<option value='".$themelist[$i]['themeid']."-".$themelist[$i]['themename']."' selected='selected'>".ucwords(strtolower($themelist[$i]['themename']))."</option>";
						}
						else
						{	
							$strTheme .= "<option value='".$themelist[$i]['themeid']."-".$themelist[$i]['themename']."'>".ucwords(strtolower($themelist[$i]['themename']))."</option>";
						}
					}
				}
				unset($testclass);
				return $strTheme;	
	}
	
	function CityName($cityid)
	{
	
			$testclass		=	new AllTables();
			$sql			=	"SELECT cityname from mstcity where cityid='$cityid'";
			$citylist 		=	$testclass->getInfo('',$sql);
			if(is_array($citylist))
			{
					$cityname	=	$citylist[0]['cityname'];
					return $cityname;
			}
	}
	function CountryName($countryid)
	{
	
			$testclass		=	new AllTables();
			$sql			=	"SELECT countryname from mstcountry where countryid='$countryid'";
			$countrylist 		=	$testclass->getInfo('',$sql);
			if(is_array($countrylist))
			{
					$countryname	=	$countrylist[0]['countryname'];
					return $countryname;
			}
	}
	function RegionName($regionid)
	{
	
			$testclass		=	new AllTables();
			$sql			=	"SELECT regionname from  mstregion where regionid='$regionid'";
			$Regionlist 		=	$testclass->getInfo('',$sql);
			if(is_array($Regionlist))
			{
					$regionname	=	$Regionlist[0]['regionname'];
					return $regionname;
			}
	}
	function LocationName($locationid)
	{
	
			$testclass				=	new AllTables();
			$sqlLocation			=	"SELECT locationname from  mstlocation where locationid='$locationid'";
			$LocationList 			=	$testclass->getInfo('',$sqlLocation);
			if(is_array($LocationList))
			{
					$locationname	=	$LocationList[0]['locationname'];
					//unset($testclass);
					return $locationname;
			}
	}
	function ThemeName($themeid)
	{
	
			$testclass			=	new AllTables();
			$sqlthemeid			=	"SELECT themename from  msttheme where themeid='$themeid'";
			$themelist 			=	$testclass->getInfo('',$sqlthemeid);
			if(is_array($themelist))
			{
					$themename	=	$themelist[0]['themename'];
					return $themename;
					unset($testclass);
			}
	}
	function getPackageDetails($tourpackageid)
	{
			$testclass			=	new AllTables();
			$sqlpack			=	"SELECT * from  GTR_tourpackages where tourpackageid='$tourpackageid'";
			$packlist 			=	$testclass->getInfo('',$sqlpack);
			if(is_array($packlist))
			{
					//$packname	=	$packlist[0]['tourpackagetitle'];
					return $packlist;
					unset($testclass);
			}
	}
	function PackageName($tourpackageid)
	{
	
			$testclass			=	new AllTables();
			$sqlpack			=	"SELECT * from  GTR_tourpackages where tourpackageid='$tourpackageid'";
			$packlist 			=	$testclass->getInfo('',$sqlpack);
			if(is_array($packlist))
			{
					$packname	=	$packlist[0]['tourpackagetitle'];
					return $packname;
					unset($testclass);
			}
	}
		function package_pdffilename($tourpackageid)
	{
	
			$testclass			=	new AllTables();
			$sqlpack			=	"SELECT pdf_filepath from  GTR_tourpackages where tourpackageid='$tourpackageid'";
			$packlist 			=	$testclass->getInfo('',$sqlpack);
			if(is_array($packlist))
			{
					$packname	=	$packlist[0]['pdf_filepath'];
					return $packname;
					unset($testclass);
			}
	}
	function getPackageListForCombo()
	{
		$packsql		=		"SELECT tourpackageid,tourpackagetitle FROM GTR_tourpackages where packagedeleted='0' group by tourpackagetitle ORDER BY tourpackagetitle";
		$testclass		=		new AllTables();
		$packagelist	=		$testclass->getInfo('',$packsql);
		$totalpack	=	count($packagelist);
		if($totalpack > 0)
			{
					$totalpack	=	count($packagelist);
					for($i=0;$i<$totalpack;$i++)
					{
							$tourpackageid				=		$packagelist[$i]['tourpackageid'];
							$tourpackagetitle			=		preview_text($packagelist[$i]['tourpackagetitle'],'25');
							
							$strPackage		.=		'<option value="'.$tourpackageid.'" >'.$tourpackagetitle.'</option>';
					}
					return $strPackage;
			}
	}
	function PackageListForHomePage($regionid,$countryid,$themeid,$pagename,$numberofday='')
	{
			$testclass		=		new AllTables();
			$numberofnights	=	$numberofday-1;
			
			//Condition starts here for serch.php
		if($pagename=='search.php')	
		{
			if($regionid!="")
				{
					 //$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}
			else if($countryid!="")
				{
					 //$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.countryid='$countryid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.countryid='$countryid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}
			else if($themeid!="")
				{
					 //$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}			
			else
				{	
				$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
		
			/*if($regionid!="" && $countryid!="" && $themeid!="")
			{
					$packsql		=		"SELECT a.tourpackageid, a.tourpackagedesc,a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and a.countryid='$countryid' and a.themeid='$themeid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid!="" && $countryid!="" && $themeid=="")
			{
					$packsql		=		"SELECT a.tourpackageid, a.tourpackagedesc,a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and a.countryid='$countryid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid!="" && $countryid=="" && $themeid=="")
			{
				$packsql		=		"SELECT a.tourpackageid, a.tourpackagedesc,a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid=="" && $countryid!="" && $themeid!="")
			{
				$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and a.countryid='$countryid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid=="" && $countryid!="" && $themeid=="")
			{
					$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where  a.countryid='$countryid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid=="" && $countryid=="" && $themeid!="")
			{
				$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and noofnights='$numberofnights'  and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			else if($regionid!="" && $countryid=="" && $themeid!="")
			{
					$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and a.regionid='$regionid' and noofnights='$numberofnights' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
		else
			{	
				$packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}*/
		}	
			
			else
			{
					$packsql		=		"SELECT a.tourpackageid, a.tourpackagetitle,a.countryid,a.tourpackagedesc, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.packagedeleted='0' and isspecialpackage='1' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
			}
			
			$packagelist	=		$testclass->getInfo('',$packsql);
			$totalpack	=	count($packagelist);
			if($totalpack>0)
			{
					$totalpack	=	count($packagelist);
					for($i=0;$i<$totalpack;$i++)
					{
							$tourpackageid				=		$packagelist[$i]['tourpackageid'];
							$tourpackagetitle			=		preview_text($packagelist[$i]['tourpackagetitle'],'16');
							$tourpackagedesc			=		preview_text($packagelist[$i]['tourpackagedesc'],'60');
							$countryid					=		CountryName($packagelist[$i]['countryid']);
							$itineraryphotopath			=		$packagelist[$i]['itineraryphotopath'];
							if($itineraryphotopath!="")
							{
									 $imagesrc						=	PACKAGE_IMAGE.'thumb/'.$itineraryphotopath;
							}
							else
							{
									 $imagesrc						=	IMAGE_DIR.'mail_photo.jpeg';
							}
							$url						=		DOC_ROOT.'packagedetails.php?tourpackageid='.$tourpackageid;
							$moreurl					=		IMAGE_DIR.'gree_arr.jpg';
							if($pagename=='search.php')	
							{
							
											$strPackage		.=		'<div class="packages">';
											$strPackage		.=		'<div class="packageimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="181" height="120" class="imagesborder" /></a></div>';
											$strPackage		.=		'<div class="packagehading blacktwo"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
											$strPackage		.=		'<div class="packagedetails blacknormal">"'.$tourpackagedesc.'"';
											$strPackage		.=		'</div>';
											$strPackage		.=		'<div class="more "> <a class="readmore1" href="'.$url.'">...More</a></div>';
											$strPackage		.=		'</div>';
							}
							else
							{
									$strPackage					.=		'<div class="specialpackagesinner">';
									$strPackage					.=		'<div class="specialpackageshading whitetext"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
									$strPackage					.=		'<div class="specialpackagesimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="145" height="108"  class="imagesborder2"/></a></div>';
									$strPackage					.=		'<div class="specialpackagesimgmore"><a  class="whitetext" href="'.$url.'">'.$countryid.' >></a></div>';
									$strPackage					.=		'</div>';
							}
							
					}
					return $strPackage;
			}
			else
			{
				$CountryName	=	ProperCase(CountryName($countryid));
				$RegionName		=	ProperCase(RegionName($regionid));
				$ThemeName		=	ProperCase(ThemeName($themeid));
				
				$strPackage		.=		'<div class="panelgroup-info-holder">';
				$strPackage		.=		'<p class="redtext"><strong>No Related Package Found</strong></p><br/>See Other Packege For '.$CountryName. $RegionName.$ThemeName;
				$strPackage		.=		'</div>';
				//default detail
			if($regionid!="")
				{
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}
			if($countryid!="")
				{
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.countryid='$countryid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}
			if($themeid!="")
				{
					 $packsql		=		"SELECT a.tourpackageid,a.tourpackagedesc, a.tourpackagetitle,a.countryid, b.itineraryphotopath FROM GTR_tourpackages a left JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.themeid='$themeid' and  a.packagedeleted='0' group by a.tourpackagetitle ORDER BY a.tourpackageid DESC";
				}	
			$packagelist	=		$testclass->getInfo('',$packsql);
			$totalpack	=	count($packagelist);
			if($totalpack>0)
			{
					$totalpack	=	count($packagelist);
					for($i=0;$i<$totalpack;$i++)
					{
							$tourpackageid				=		$packagelist[$i]['tourpackageid'];
							$tourpackagetitle			=		preview_text($packagelist[$i]['tourpackagetitle'],'16');
							$tourpackagedesc			=		preview_text($packagelist[$i]['tourpackagedesc'],'60');
							$countryid					=		CountryName($packagelist[$i]['countryid']);
							$itineraryphotopath			=		$packagelist[$i]['itineraryphotopath'];
							if($itineraryphotopath!="")
							{
									 $imagesrc						=	PACKAGE_IMAGE.'thumb/'.$itineraryphotopath;
							}
							else
							{
									 $imagesrc						=	IMAGE_DIR.'mail_photo.jpeg';
							}
							$url						=		DOC_ROOT.'packagedetails.php?tourpackageid='.$tourpackageid;
							$moreurl					=		IMAGE_DIR.'gree_arr.jpg';
							if($pagename=='search.php')	
							{
							
											$strPackage		.=		'<div class="packages">';
											$strPackage		.=		'<div class="packageimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="181" height="120" class="imagesborder" /></a></div>';
											$strPackage		.=		'<div class="packagehading blacktwo"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
											$strPackage		.=		'<div class="packagedetails blacknormal">"'.$tourpackagedesc.'"';
											$strPackage		.=		'</div>';
											$strPackage		.=		'<div class="more "> <a class="readmore1" href="'.$url.'">...More</a></div>';
											$strPackage		.=		'</div>';
							}
							else
							{
									$strPackage					.=		'<div class="specialpackagesinner">';
									$strPackage					.=		'<div class="specialpackageshading whitetext"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
									$strPackage					.=		'<div class="specialpackagesimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="145" height="108"  class="imagesborder2"/></a></div>';
									$strPackage					.=		'<div class="specialpackagesimgmore"><a  class="whitetext" href="'.$url.'">'.$countryid.' >></a></div>';
									$strPackage					.=		'</div>';
							}
							
					}
				}
				return $strPackage;
			}
	}
	function DestinationListForHomePage()
	{
			$testclass		=		new AllTables();
			$destsql		=		"select * from mstlocation order by locationname";
			$DestList		=		$testclass->getInfo('',$destsql);
			if(is_array($DestList))
			{
					$totaldestination	=	count($DestList);
					for($i=0;$i<$totaldestination;$i++)
					{
							$locationid				=		$DestList[$i]['locationid'];
							$locationname			=		$DestList[$i]['locationname'];
							
							$url						=		DOC_ROOT.'locations.php?locationid='.$locationid;
							
							//$strDestination					.=		'<li><a href="'.$url.'" id="current">'.$locationname.'</a></li>';
							$strDestination					.=		'<li><a href="'.$url.'">'.$locationname.'</a></li>';
							
							
					}
					return $strDestination;
			}
			
	}
	function RelatedPackageForLacation($locationid)
	{
			$testclass		=		new AllTables();
			if($locationid!='')
			{
					 $locationname			=		LocationName($locationid);
					 $packagesql			=		"select regionid from mstlocation where locationid='$locationid'";
			}
			$Detaillist		=		$testclass->getInfo('',$packagesql);
			if(is_array($Detaillist))
			{
					$totaldestination	=	count($Detaillist);
					for($i=0;$i<$totaldestination;$i++)
					{
							$regionid				=		$Detaillist[$i]['regionid'];
							//$relatedpacksql			=		"select * from GTR_tourpackages where regionid='$regionid'";
							$relatedpacksql			=		"SELECT a.tourpackageid, a.tourpackagetitle, b.itineraryphotopath FROM GTR_tourpackages a INNER JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and a.packagedeleted='0' group by a.tourpackagetitle";
							//echo $relatedpacksql;
							$TourPackList			=		$testclass->getInfo('',$relatedpacksql);
							if(is_array($TourPackList))
							{
									
									$totalpacklist			=	count($TourPackList);
									for($i=0;$i<$totalpacklist;$i++)
									{
											$tourpackageid				=	$TourPackList[$i]['tourpackageid'];
											$tourpackagetitle			=	$TourPackList[$i]['tourpackagetitle'];
											$itineraryphotopath			=	$TourPackList[$i]['itineraryphotopath'];
											if($itineraryphotopath!="")
											{
													 $imagesrc						=	PACKAGE_IMAGE.'thumb/'.$itineraryphotopath;
											}
											else
											{
													 $imagesrc						=	IMAGE_DIR.'mail_photo.jpeg';
											}
											$url						=		DOC_ROOT.'packagedetails.php?tourpackageid='.$tourpackageid;
											$moreurl					=		IMAGE_DIR.'gree_arr.jpg';
											//$img					=		IMAGE_DIR.'lo_img1.jpg';
											$strPackList		.=		'<div class="locationspackagesinner">';
											$strPackList		.=		'<div class="locationspackagesname redtext"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
											$strPackList		.=		'<div class="locationspackagesimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="180" height="126" /></a></div>';
											$strPackList		.=		'<div class="locationspackagesmore"><a  class="redtext"href="'.$url.'">More<img src="'.$moreurl.'" width="15" height="11" /></a></div>';
											$strPackList		.=		'</div>';
									}
										return $strPackList;
							}
							else
							{
									
									$strPackList		.=		'<div class="panelgroup-info-holder">';
									$strPackList		.=		'<p class="redtext"><strong>No package are available for '.$locationname.'</strong></p>';
									$strPackList		.=		'</div>';
									return $strPackList;
							}
					}
			}
	}
	function RaletedTourPackageListForHomePage($regionid)
	{
			$testclass			=	new AllTables();
			$sqltourpack		=	"SELECT a.tourpackageid,a.tourpackagetitle,b.itineraryphotopath,a.tourpackagedesc FROM GTR_tourpackages a INNER JOIN GTR_tourpackageItinerary b ON b.tourpackageid = a.tourpackageid where a.regionid='$regionid' and a.packagedeleted='0' group by a.tourpackagetitle order by a.tourpackageid desc";
			//echo $sqltourpack;
			$TourPackList		=	$testclass->getInfo('',$sqltourpack);
			if(is_array($TourPackList))
			{
						$totalrow		=		count($TourPackList);
						for($i=0;$i<$totalrow;$i++)
						{
							$tourpackageid				=	$TourPackList[$i]['tourpackageid'];
							$tourpackagetitle			=	preview_text($TourPackList[$i]['tourpackagetitle'],15);
							$itineraryphotopath			=	$TourPackList[$i]['itineraryphotopath'];
							if($itineraryphotopath!="")
							{
									 $imagesrc						=	PACKAGE_IMAGE.'thumb/'.$itineraryphotopath;
							}
							else
							{
									 $imagesrc						=	IMAGE_DIR.'mail_photo.jpeg';
							}
							$tourpackagedesc			=		preview_text($TourPackList[$i]['tourpackagedesc'],50);
							$url						=		DOC_ROOT.'packagedetails.php?tourpackageid='.$tourpackageid;
							$moreurl					=		IMAGE_DIR.'gree_arr.jpg';
							//$img					=		IMAGE_DIR.'lo_img1.jpg';
							
							
							$strTourPackList		.=		'<div class="packages">';
							$strTourPackList		.=		'<div class="packageimg"><a href="'.$url.'"><img src="'.$imagesrc.'" width="181" height="120" class="imagesborder" /></a></div>';
							$strTourPackList		.=		'<div class="packagehading blacktwo"><a href="'.$url.'">'.$tourpackagetitle.'</a></div>';
							$strTourPackList		.=		'<div class="packagedetails blacknormal">"'.$tourpackagedesc.'"';
							$strTourPackList		.=		'</div>';
							$strTourPackList		.=		'<div class="more"> <a class="readmore1" href="'.$url.'">...More</a></div>';
							$strTourPackList		.=		'</div>';
					}
					return $strTourPackList;
			}
			else
			{			
			
						$strTourPackList		.=		'<div class="panelgroup-info-holder">';
						$strTourPackList		.=		'<p class="redtext"><strong>No Related Package Found</strong></p>';
						$strTourPackList		.=		'</div>';
						//$strTourPackList			=	"No Related Package Found";
						return $strTourPackList;
			}
	}
	function GalleryPhotoForHomePage()
	{
				$testclass				=	new AllTables();
				$galleryphotolist		=	$testclass->getInfo('',"SELECT itineraryphotopath   FROM `GTR_tourpackageItinerary` where itineraryphotopath!='' order by itineraryphotopath desc");
			if(is_array($galleryphotolist))
			{
				$rowcount		=		count($galleryphotolist);
				
				for($i=0;$i<$rowcount;$i++)
				{
						$photoimagepath	=	$galleryphotolist[$i]['itineraryphotopath'];
						$url			=	DOC_ROOT.'gallery.php';
						$galleryimg		=	PACKAGE_IMAGE.'thumb/'.$photoimagepath;
						$biggallery		=	PACKAGE_IMAGE.$photoimagepath;
						$galleryphoto				.=	'<div id="gallery" >';
						$galleryphoto	.=	'<div class="packages">';
                        $galleryphoto	.=	'<div class="packageimg"><a href="'.$biggallery.'"><img src="'.$galleryimg.'" width="181" height="120" class="imagesborder"/></a></div>';
                       	$galleryphoto	.=	'</div>';
						$galleryphoto	.=	'</div>';
						
						
				}
				
				return $galleryphoto;
			}
			else
			{
				$galleryphoto	=	"Gallery Photo Empty";
				return $galleryphoto;
			}
	}
	function GalleryVedioForHomePage()
	{
				$testclass				=	new AllTables();
				$galleryVediolist		=	$testclass->getInfo('',"SELECT PackageVideotitle,videolink,tourpackageid FROM `GTR_tourpackages` where videolink!=''");
				//echo "SELECT videolink FROM `GTR_tourpackages` where videolink!=''";
			if(is_array($galleryVediolist))
			{
				$rowcount		=		count($galleryVediolist);
				
				for($i=0;$i<$rowcount;$i++)
				{
						$Videogepath	=	$galleryVediolist[$i]['videolink'];
						//$url			=	DOC_ROOT.'video.php';
						//$galleryimg		=	$Videogepath;
						//$biggallery		=	$photoimagepath;
						//you tube vedio 
						if ($Videogepath!=''){
								$jutjub = new YouTube($Videogepath);
								//$showvideo = $jutjub->EmbedVideo();
								$showimage = $jutjub->ShowImg();
							}
		
						
						
						$galleryVedio	.=	'<div class="vedioinner">';
						//$galleryVedio	.=	'<div class="vedioleft">'.$showvideo.'</div>';
                        //$galleryVedio	.=	'<div class="vedioright">'.$showvideo.'</div>';
						$galleryVedio	.=	'<div class="vedioleft"><a href="'.DOC_ROOT.'video_details.php?videoid='.$galleryVediolist[$i]['tourpackageid'].'">'.$showimage.'<br /><strong class="lightblue">'.$galleryVediolist[$i]['PackageVideotitle'].'</strong></a></div>';
						$galleryVedio	.=	'<div class="vedioright"><a href="'.DOC_ROOT.'video_details.php?videoid='.$galleryVediolist[$i]['tourpackageid'].'">'.$showimage.'<br /><strong class="lightblue">'.$galleryVediolist[$i]['PackageVideotitle'].'</strong></a></div>';
                       	$galleryVedio	.=	'</div>';
						
						
				}
				
				return $galleryVedio;
			}
			else
			{
				$galleryVedio	=	"Gallery Vedio Empty";
				return $galleryVedio;
			}
	}
	function FooterPageLink($pagevalue)
		{
					//PageValue means, where to display in header or footer
					$footer			=	new AllTables();
					if($pagevalue!='')
					{
								$footersql		=	"Select * from mstpages where  isapproved='1' and pagecategory='0' order by pagename asc limit 0,3";
					}
					else
					{
								$footersql		=	"Select * from mstpages where isapproved='1' order by pagename asc limit 0,5";							
					}
					$pagenamelist	=	$footer->getInfo('',$footersql);
					if(is_array($pagenamelist))
					{
							$pagecount		=	count($pagenamelist);
							$pagecategory	=	'';
							for($i=0;$i<$pagecount;$i++)
							{
									$pageid				=		$pagenamelist[$i]['pageid'];
									$pagename			=		ProperCase($pagenamelist[$i]['pagename']);
									$pagelink			=		$pagenamelist[$i]['pagelink'];
									$pagecategory		=		$pagenamelist[$i]['pagecategory'];
									$url				=		DOC_ROOT.'pages/'.$pagelink.'.htm';
									$selectedlink		=		'/pages/index.php?pagename='.$pagename.'';
									if($pagevalue=='header')
									{
											// check if there are sub pages under this page
											$subpagesql = "select * from mstpages where pagecategory='$pageid' and isapproved='1'";
											$subpageslist	=	$footer->getInfo('',$subpagesql);
											if ($subpageslist)
											{
												$subpagecount = count($subpageslist);
												$footerpages		.=		'<li><a href="#" >'.$pagename.'</a>';
												$footerpages		.=		'<ul>';
												for ($j=0;$j< $subpagecount;$j++)
												{
														$subpagelink			=	$subpageslist[$i]['pagelink'];
														$subpageurl				= 	DOC_ROOT.'pages/'.$subpagelink.'.htm';
														$footerpages			.=	'<li><a href="'.$subpageurl.'">'.$subpageslist[$j]['pagename'].'</a></li>';
												}
														$footerpages			.=	'</ul></li>';
											}
											else
											{
												$footerpages		.=		'<li><a href="'.$url.'" >'.$pagename.'</a></li>';
											}	
									}
									else
									{
											$footerpages		.=		'<a href="'.$url.'" class="whitefooter">'.$pagename.'</a>   |';
									}
								
							}
							return $footerpages;
							
					}
		}
	function BannerListForHome()
	{
					$banner			=	new AllTables();
					$bannersql		=	"Select * from mstbanner order by bannerid desc limit 0,5";
					$bannerlist	=	$banner->getInfo('',$bannersql);
					if(is_array($bannerlist))
					{
						$rowcount	=	count($bannerlist);
						for($i=0;$i<$rowcount;$i++)
						{
								$bannerid		=		$bannerlist[$i]['bannerid'];
								$bannername		=		$bannerlist[$i]['bannername'];
								$image			=		$bannerlist[$i]['image'];
								$imageval		=		($image=='')?IMAGE_DIR.'mail_photo.jpeg':BANNER_IMAGE.$image;	
								$strBanner		.=		'<img src="'.$imageval.'" width="1200" height="400" />';
						}	
						return $strBanner;
						unset($banner);	
					}
	}
	function Attachement($tourpackageid)
	{
	
			
			$testclass			=	new AllTables();
			$attach				=	"SELECT pdf_filepath from  GTR_tourpackages where tourpackageid='$tourpackageid'";
			$attachlist 		=	$testclass->getInfo('',$attach);
			if(is_array($attachlist))
			{
					$pdf_filepath	=	$attachlist[0]['pdf_filepath'];
					return $pdf_filepath;
					unset($testclass);
			}
	}
	function GetTestimonial($testimonialid)
	{
					$test			=	new AllTables();
					if($testimonialid!='')
					{
							$testsql		=	"Select * from  msttestimonial where testimonialid='$testimonialid' order by testimonialid desc limit 0,2"; 
					}
					else
					{
							$testsql		=	"Select * from  msttestimonial order by testimonialid desc limit 0,2"; 
					}
					$testlist		=	$test->getInfo('',$testsql);
					if(is_array($testlist))
					{
						$rowcount	=	count($testlist);
						for($i=0;$i<$rowcount;$i++)
						{
								$testimonialid					=		$testlist[$i]['testimonialid'];
								$testimonial					=		$testlist[$i]['testimonial'];
								$testimonialbyclientname		=		ProperCase($testlist[$i]['testimonialbyclientname']);
								$testimonialdate				=		date("d M Y",strtotime($testlist[$i]['testimonialdate']));
								
								$strTestimonial		.=		'<div class="testimonialstext">'.$testimonial.'';
								//$strTestimonial		.=		'"'.trim($testimonial).'"';
								$strTestimonial		.=		'<br />';
								$strTestimonial		.=		'</div>';
								$strTestimonial		.=		'<div class="testimonialsname blacknormal2">'.$testimonialbyclientname.'<br />';
								$strTestimonial		.=		'Date :&nbsp;'.$testimonialdate.'';
                  				$strTestimonial		.=		'</div>';
								
						}	
						return $strTestimonial;
						unset($test);	
					}
					else
					{	
							$strTestimonial		=	"There are no testimonial";
							return $strTestimonial;
					}
	}
	function HeaderSubMenuListForRegion($regionid)
	{
			$menu			=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select tourpackageid,tourpackagetitle from GTR_tourpackages where regionid='$regionid' and packagedeleted='0' order by tourpackageid limit 0,20 ");
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$tourpackageid			=		$menulist[$i]['tourpackageid'];
							$tourpackagetitle		=		$menulist[$i]['tourpackagetitle'];
							$link					=		DOC_ROOT.'packagedetails.php?tourpackageid='.$tourpackageid;
							$subMenu				.=		'<li><a href="'.$link.'">'.$tourpackagetitle.'</a></li>';
							
					}
					return $subMenu;
					
			}
			/*else
			{
						$subMenu				.=		'<li>Not Found</li>';
						return $subMenu;
			}*/
	}
	function HeaderSubMenuListForProductCategory()
	{
			$menu			=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select categoryid,categoryname,categorylink from mstcategory order by homepageorder ");
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$tourpackageid			=		$menulist[$i]['categoryid'];
							$tourpackagetitle		=		$menulist[$i]['categoryname'];
							$categorylink			=		$menulist[$i]['categorylink'];
							$link					=		DOC_ROOT.'cats-'.$categorylink.'.htm';
							$subMenu				.=		'<li><a href="'.$link.'">'.$tourpackagetitle.'</a></li>';
							
					}
					return $subMenu;
					
			}
			/*else
			{
						$subMenu				.=		'<li>Not Found</li>';
						return $subMenu;
			}*/
	}
	function getProductNamesInList($categoryid)
	{
			$menu			=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select productid,productname,productlink from mstproducts where categoryid='$categoryid' limit 0,50 ");
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$tourpackageid			=		$menulist[$i]['productid'];
							$tourpackagetitle		=		$menulist[$i]['productname'];
							$categorylink			=		$menulist[$i]['productlink'];
							$link					=		DOC_ROOT.'prods-'.$categorylink.'.htm';
							$subMenu				.=		'<li><a href="'.$link.'">'.$tourpackagetitle.'</a></li>';
							
					}
					return $subMenu;
					
			}
	}
	function returnSelected($value1,$value2)
	{
		if ($value1==$value2)
		{
			return "selected='selected'";
		} 
		 else
		{
			return "";
		} 
	}
	function toAscii($str, $replace=array(), $delimiter='-') {
	if( !empty($replace) ) {
		$str = str_replace((array)$replace, ' ', $str);
		}
		$clean = iconv('UTF-8', 'ASCII//TRANSLIT', $str);
		$clean = preg_replace("/[^a-zA-Z0-9\/_|+ -]/", '', $clean);
		$clean = strtolower(trim($clean, '-'));
		$clean = preg_replace("/[\/_|+ -]+/", $delimiter, $clean);

		return $clean;
	}
	
	
	
	
	
	function getExhibitionListForCombo($exhibitionid='',$countryid='',$countryname='')
	{
		$testclass		=	new AllTables();
		
		if ($countryid!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid ='".$countryid."' ORDER BY State asc");
		}
		else if($countryname!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid in (Select countryid from mstcountry where countryname ='".$countryname."') ORDER BY State");
		}
		else
		{
			$statelist = $testclass->getInfo("","select * FROM trnexhibition ORDER BY exhibitionid");
			//echo $statelist;
		}
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($exhibitionid)==$statelist[$i]['exhibitionid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['exhibitionid']."-".$statelist[$i]['exhibitionname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['exhibitionname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['exhibitionid']."-".$statelist[$i]['exhibitionname']."'>".ucwords(strtolower($statelist[$i]['exhibitionname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}	
	
	
	
	
	function getArtistListForCombo($artistid='',$countryid='',$countryname='')
	{
		$testclass		=	new AllTables();
		
		if ($countryid!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid ='".$countryid."' ORDER BY State asc");
		}
		else if($countryname!='')
		{
			$statelist = $testclass->getInfo("","SELECT * FROM mststate WHERE countryid in (Select countryid from mstcountry where countryname ='".$countryname."') ORDER BY State");
		}
		else
		{
			$statelist = $testclass->getInfo("","select * FROM mstartist ORDER BY artistid");
			//echo $statelist;
		}
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($artistid)==$statelist[$i]['artistid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['artistid']."-".$statelist[$i]['artistname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['artistname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['artistid']."-".$statelist[$i]['artistname']."'>".ucwords(strtolower($statelist[$i]['artistname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}

	function getArtistNamesInExhibition($exhibitionid='')
	{
			$menu			=	new AllTables();
			if ($exhibitionid !='')
			{
				$menulist		=	$menu->getInfo('',"Select a.artistid,artistname,artisturl from mstartist a inner join mstpaintings b on a.artistid=b.artistid inner join trnexhibition c on b.exhibitionid=c.exhibitionid where c.exhibitionid='$exhibitionid'  group by artistname order by artistname asc ");

			}
			else
			{
				$menulist		=	$menu->getInfo('',"Select artistid,artistname,artisturl from mstartist order by artistname asc");
			}	
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					$subMenu 			= '<ul class="list-inline artists">';
					for($i=0;$i<$rowcount;$i++)
					{
							$artistid				=		$menulist[$i]['artistid'];
							$artistname				=		strtoupper($menulist[$i]['artistname']);	
							$artisturl				=		$menulist[$i]['artisturl'];
							$artistname_url		=		replaceForURL($artistname);	
							$artisturl				=		$menulist[$i]['artisturl'];
							//$link					=		DOC_ROOT.'prods-'.$categorylink.'.htm';
							$artisturl				=     "Artist-".$artistname_url."-".$artistid.".html";			
							
							
							//$link					=		DOC_ROOT.'artgallery.php?artistname='.$artisturl;
														
							$subMenu				.=		'<li><a href="'.$artisturl.'">'.$artistname.'</a></li>';
							
					}
					$subMenu .= '</ul>';
					return $subMenu;
					
			}
	}
	function getArtistNamesInList($categoryid='')
	{
			$menu			=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select artistid,artistname,artisturl from mstartist order by artistname asc");
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$artistid				=		$menulist[$i]['artistid'];
							$artistname				=		strtoupper($menulist[$i]['artistname']);
							$artistname_url		=		replaceForURL($artistname);	
							$artisturl				=		$menulist[$i]['artisturl'];
							//$link					=		DOC_ROOT.'prods-'.$categorylink.'.htm';
							$artisturl				=     "Artist-".$artistname_url."-".$artistid.".html";			
							
							
							//$link					=		DOC_ROOT.'artgallery.php?artistname='.$artisturl;
														
							$subMenu				.=		'<li><a href="'.$artisturl.'">'.$artistname.'</a></li>';
							
					}
					return $subMenu;
					
			}
	}

function replaceForURL($strOrgUrl)
{
	$strOrgUrl = trim($strOrgUrl);
	$ReturnURL = str_replace(" ","-",$strOrgUrl);
	$ReturnURL = str_replace("-&-","-_and_-",$ReturnURL);
	$ReturnURL = str_replace("%2F","_s_",$ReturnURL);
	$ReturnURL = str_replace("/","_s_",$ReturnURL);
	$ReturnURL = str_replace("\\","",$ReturnURL);
	$ReturnURL = str_replace("(","_bb_",$ReturnURL);
	$ReturnURL = str_replace(")","_rbrb_",$ReturnURL);
	$ReturnURL = str_replace("&#40;","_bb_",$ReturnURL);
	$ReturnURL = str_replace("&#41;","_rbrb_",$ReturnURL);
	$ReturnURL = str_replace("#40;","_bb_",$ReturnURL);
	$ReturnURL = str_replace("#41;","_rbrb_",$ReturnURL);
	$ReturnURL = str_replace("#45;","-",$ReturnURL);
	$ReturnURL = str_replace("\"","",$ReturnURL);
	$ReturnURL = str_replace("\'","",$ReturnURL);
	$ReturnURL = str_replace("#","_",$ReturnURL);
	$ReturnURL = str_replace(".","",$ReturnURL);
	$ReturnURL = strtolower(str_replace("%","",$ReturnURL));
	return $ReturnURL;
}

function replaceFromURL($strURL)
{
	
	$replaceURL = str_replace("-&amp;-"," & ",$strURL);
	$replaceURL = str_replace("-_and_-","-&-",$replaceURL);
	$replaceURL = str_replace("_n_","&",$replaceURL);
	$replaceURL = str_replace("_s_","/",$replaceURL);
	$replaceURL = str_replace("--"," & ",$replaceURL);
	$replaceURL = str_replace("_bb_","(",$replaceURL);
	$replaceURL = str_replace("_rbrb_",")",$replaceURL);
	$replaceURL = str_replace("-"," ",$replaceURL);
	$replaceURL = str_replace("_"," ",$replaceURL);
	return $replaceURL;
}
	
	
function newPaintings()
{			
$newobj			=	new AllTables();
			$sql = "SELECT artistname,paintingid,paintingurl,a.p_thumbphotoname as paintingimg FROM mstpaintings a
inner join mstartist b on a.artistid=b.artistid
where newpainting=1 order by paintingid desc  limit 0,50";
			//echo $sql;
			$paintarray = $newobj -> getInfo('',$sql);
			//print_r($paintarray	);
			
			$rowcount = count($paintarray);
			//echo "<br>rowcount ".$rowcount;

				for($i=0;$i<$rowcount;$i++)
				{
					//$artistid 			= $paintarray[$i]['artistid'];
					//$title 			   = $paintarray[$i]['title'];
					$artistname 		= $paintarray[$i]['artistname'];
					//$artisturl 			= htmlentities($paintarray[$i]['artisturl']);
					
					/*
					$sql2 = "SELECT * FROM mstpaintings b WHERE b.artistid = ".$artistid." limit 0,1";
					//echo $sql2;
					$paintingsarray = $newobj -> getInfo('',$sql2);
					//print_r ($paintingsarray);
					$p_thumbphotoname 	= "";
					if(is_array($paintingsarray))
					{*/
					   $artistname 		= $paintarray[$i]['artistname'];
						$paintingid 	= $paintarray[$i]['paintingid'];
						$paintingimg 	= $paintarray[$i]['paintingimg'];
						$paintingurl 		= replaceForURL($paintarray[$i]['paintingurl']);					
						$finalurl 			= $paintingurl."-".$paintingid.".html"; 
					//}
					
					
//echo "<div class='col-md-3 text-center '>";
echo "";

echo " <a href='Painting-".$finalurl."'  >";
echo "<img  src='".PRODUCT_PHOTO_THUMB_PATH."".$paintingimg."' class='img-responsive center-block item_image product_image' style='margin-left: 10px; float:left; margin-top: 10px' /><div class='clearfix'></div><div class='h5 text-center' style='text-decoration:none;margin-top:-10px;color:white;background-color:rgba(0,0,0,0.3);position: absolute;bottom: 8px;left: 18px;right: 18px;padding:10px'>".$artistname."</div>";
echo "</a> ";

	  

				}
/*
					$artistname1 		= $paintarray[4]['artistname'];
					$p_thumbphotoname1 	= $paintarray[4]['p_thumbphotoname'];
					$artistid1			= $paintarray[4]['artistid'];
					$artisturl1			= htmlentities($paintarray[4]['artisturl']);
					
					$artistname2 		= $paintarray[5]['artistname'];
					$p_thumbphotoname2 	= $paintarray[5]['p_thumbphotoname'];
					$artistid2			= $paintarray[5]['artistid'];
					$artisturl2			= htmlentities($paintarray[5]['artisturl']);
					
					$artistname3 		= $paintarray[6]['artistname'];
					$p_thumbphotoname3 	= $paintarray[6]['p_thumbphotoname'];
					//echo $p_thumbphotoname3;
					$artistid3			= $paintarray[6]['artistid'];
					$artisturl3			= htmlentities($paintarray[6]['artisturl']);
					
					$artistname4 		= $paintarray[7]['artistname'];
					$p_thumbphotoname4 	= $paintarray[7]['p_thumbphotoname'];
					$artistid4			= $paintarray[7]['artistid'];
					$artisturl4			= htmlentities($paintarray[7]['artisturl']);
					
	*/	
}

  function BannerNew()
	{	  
		   $subMenu=''; 	
			$menu			=	new AllTables();
			$sql="SELECT b. p_thumbphotoname as paintingimage,a.artistid,a.artistname,a.artisturl,b.paintingurl,b.paintingid 
			      FROM mstartist a 
					inner join mstpaintings b on b.artistid=a.artistid  
				   where artistforbanner=1 and bannerpainting=1
				   group by artistid";
			//echo $sql;
			$menulist	=	$menu->getInfo('',$sql);
			//print_r($menulist);				
			if(is_array($menulist))
			{
					$rowcount			      =		count($menulist);
					$startol    ='<ol class="carousel-indicators">';
    
		      for($j=0;$j<$rowcount;$j++)
		      {
		      	      if($j==0)
						  {
						  	  $activeol  = 'class="active"';
						  	
						  }
						  else 
						  {
						  	 $activeol  = '';
						  	 
						  }
		      	
		    	    $li .='<li data-target="#myCarousel" data-slide-to="0" '.$activeol.'></li>';
		    	}
		    	$endol    ='</ol>';
    	       $dataslider = $startol.$li.$endol;
					$divstart					=     '<div class="carousel-inner">';
				   $divend                 =     '</div>';
					for($i=0;$i<$rowcount;$i++)
					{
						  if($i==0)
						  {
						  	  $anctive  = '<div class="item active">';
						  	
						  }
						  else 
						  {
						  	 $anctive  = '<div class="item">';
						  	 
						  }
							
							$artistname		         =		$menulist[$i]['artistname'];
							$paintingimage			=		$menulist[$i]['paintingimage'];							
							
							$artisturl				=		$menulist[$i]['artisturl'];
							$artistid			=		$menulist[$i]['artistid'];
							
							$link				=     "Artist-".$artisturl."-".$artistid.".html";
							
							$subMenu   .= $anctive.'<img src="images/sliderback.jpg" style="width:100%;">
							<div class="carousel-caption">
       <div class="col-md-12 col-sm-12">
	   <div class="col-md-6 col-sm-6 col-xs-6 slider_img">
	   <br> 
	   <img src="'.PRODUCT_PHOTO_PATH.$paintingimage.'" class="img-responsive  ">
	   </div>
	   <div class="col-md-6 col-sm-6 col-xs-6">

	      <div class="h3">Artist</div>
		
		   
	   <div class="h2 carousel_name">'.$artistname.'</div>
	   <br><br> <br><br>
	   <span type="button" class="btn btn-lg"><a href="'.$link.'" style="text-decoration:underline">Explore More</a></span>
	   </div>
	   </div>
	   </div>
      </div>';
					}
					
					$mainmenu   =  $dataslider.$divstart.$subMenu.$divend;
					return $mainmenu;
					
			}
			
			
	}
	
	  function BannerNewforecom($categoryid="")
	{
		  
		   $subMenu=''; 	
			$menu			=	new AllTables();
			$bannersql		=	"Select * from mstbanner where categoryid= ".$categoryid." order by bannerid ASC";
			$menulist	=	$menu->getInfo('',$bannersql);
					
						
			//print_r($menulist);				
			if(is_array($menulist))
			{
					$rowcount			      =		count($menulist);
					$divstart					=     '<div class="carousel-inner">';
				   $divend                 =     '</div>';
					for($i=0;$i<$rowcount;$i++)
					{
						  if($i==0)
						  {
						  	  $anctive  = '<div class="item active">';
						  	
						  }
						  else 
						  {
						  	 $anctive  = '<div class="item">';
						  	 
						  	}
							
							$bannername		         =		$menulist[$i]['bannername'];
							$bannerphotothumb			=		$menulist[$i]['bannerphotothumb'];							
							

							
							$subMenu				     .=		$anctive.'<a href="#"><img style="width:100%;" src="'.PRODUCT_PHOTO_PATH.$bannerphotothumb.'" alt="'.$bannername.'"></a></div>';
					}
					
					$mainmenu   =  $divstart.$subMenu.$divend;
					return $mainmenu;
					
			}
			
			
	}
		function NumberOfItem($G_sessionid='',$G_customerId='')
	{
			$subMenu    =  "";
			$menu			=	new AllTables();
			
			if($G_sessionid <> '') 
			{
				
			  $menulist		=	$menu->getInfo('',"Select * from tmpcart where usersessionid='".$G_sessionid."'");
			  $menucount			=		count($menulist);
			  //rt_r($menucount);
			}
			if($G_customerId <> '')
			{
				$menulist		=	$menu->getInfo('',"Select * from tmpcart where customerId='".$G_customerId."'");
				 $menucount			=		count($menulist);
				 
		   }
			
				
				
				if($menucount == 0)
				{
					$itemcount			=		0;
				}
				else
				{
					$itemcount			=		count($menulist);
				}
				
           		return $itemcount;
					
			
	}
	function getUserIP()
	{
	    $client  = @$_SERVER['HTTP_CLIENT_IP'];
	    $forward = @$_SERVER['HTTP_X_FORWARDED_FOR'];
	    $remote  = $_SERVER['REMOTE_ADDR'];
	
	    if(filter_var($client, FILTER_VALIDATE_IP))
	    {
	        $ip = $client;
	    }
	    elseif(filter_var($forward, FILTER_VALIDATE_IP))
	    {
	        $ip = $forward;
	    }
	    else
	    {
	        $ip = $remote;
	    }
	
	    return $ip;
	}
	function View_cart_subtotal($productid='',$quantity='')
	{		
	
		$subMenu			=	'';
		$subtotal		= 0;

		if ($productid!='')
		{
			$menu				=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select * from mstproducts  where productid='".$productid."'");
			
			//echo $sql="Select * from mstpaintings where painting='".$productid."'";
         if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
           			$productprice			=		$menulist[$i]['productprice'];
           			
           			$subtotal				=	   $productprice *$quantity;
	
           		}
			}	
		}
		return $subtotal;
			
	}
	
	function getcategorylistcombo($categoryid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mstcategory ORDER BY categoryid");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($categoryid)==$statelist[$i]['categoryid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['categoryid']."-".$statelist[$i]['categoryname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['categoryname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['categoryid']."-".$statelist[$i]['categoryname']."'>".ucwords(strtolower($statelist[$i]['categoryname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	function getstylelistcombo($styleid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mststyle ORDER BY styleid");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($styleid)==$statelist[$i]['styleid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['styleid']."-".$statelist[$i]['stylename']."' selected='selected'>".ucwords(strtolower($statelist[$i]['stylename']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['styleid']."-".$statelist[$i]['stylename']."'>".ucwords(strtolower($statelist[$i]['stylename']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	function getmediumlistcombo($mediumid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mstmedium ORDER BY mediumid");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($mediumid)==$statelist[$i]['mediumid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['mediumid']."-".$statelist[$i]['mediumname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['mediumname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['mediumid']."-".$statelist[$i]['mediumname']."'>".ucwords(strtolower($statelist[$i]['mediumname']))."</option>";
				}
			}
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	
	function getCategoryList()
	{
					$footer			=	new AllTables();
					$footersql		=	"Select * from mstcategory ";
					$pagenamelist	=	$footer->getInfo('',$footersql);
					
							$pagecount		=	count($pagenamelist);
							for($i=0;$i<$pagecount;$i++)
							{
									$categoryid				=		$pagenamelist[$i]['categoryid'];
									$categoryname			=		ProperCase($pagenamelist[$i]['categoryname']);
									$categorylink			=		toAscii($categoryname);	
							      $link					=		DOC_ROOT.'category-'.$categorylink.'-'.$categoryid.'.html';
									$subMenu				.=		'<li><a href="'.$link.'">'.$categoryname.'</a></li>';
							}
							return $subMenu;
				
		}
		
	function getRecipeList()
	{
					$footer			=	new AllTables();
					$footersql		=	"Select * from mstrecipe ";
					$pagenamelist	=	$footer->getInfo('',$footersql);
					
							$pagecount		=	count($pagenamelist);
							for($i=0;$i<$pagecount;$i++)
							{
									$id				=		$pagenamelist[$i]['id'];
									$name				=		ProperCase($pagenamelist[$i]['name']);
									$recipelink    = 		toAscii($name);
									$link				=		DOC_ROOT.'recipe-'.$recipelink.'-'.$id.'.html';
									$subMenu			.=		'<li><a href="'.$link.'">'.$name.'</a></li>';
							}
							return $subMenu;
				
		}
		
	function getcolorlistcombo($colorid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mstcolor ORDER BY colorid");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($colorid)==$statelist[$i]['colorid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['colorid']."-".$statelist[$i]['colorname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['colorname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['colorid']."-".$statelist[$i]['colorname']."'>".ucwords(strtolower($statelist[$i]['colorname']))."</option>";
				}
			}
			
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	function getcolorComboCheckbox($colorid='')
	{
		$testclass			=	new AllTables();
		$grouplist	=	$testclass->getInfo("","select * FROM mstcolor ORDER BY colorid");
			
		$rowcount = count($grouplist);
		
		$strgroupList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				if($colorid==$grouplist[$i]['colorid'])
				{
					
					$strgroupList .= '<input type="checkbox" colorid = "'.$grouplist[$i]["colorid"].'" name="selected_color[]" value="'.$grouplist[$i]["colorid"].'">'
											.ucwords(strtolower($grouplist[$i]["colorname"]));
				}
				else
				{	
				
					$strgroupList .= '<input type="checkbox" colorid = "'.$grouplist[$i]["colorid"].'" name="selected_color[]" value="'.$grouplist[$i]["colorid"].'">'
											.ucwords(strtolower($grouplist[$i]["colorname"]));
				}
			}
		}
		return $strgroupList;
	}
	
	function getcolorComboCheckboxnew($paintingid)
	{
			$testclass			=	new AllTables();
			$claimlist	=	$testclass->getInfo("","select * FROM mstcolor ORDER BY colorid");
			
		   $claimlistcount 		=	count($claimlist);
			//echo $sql;
	      $sql1	=	"SELECT * FROM trnpaintingcolor where paintingid=".$paintingid;

			$doclist1	   =	$testclass->getInfo('',$sql1);

		$count1 		=	count($doclist1);
		for($i=0;$i<$claimlistcount;$i++) 
		{ 
			$claimlistid 					= $claimlist[$i]['colorid'];
		   $claimlistname 				= $claimlist[$i]['colorname'];
			for($j=0;$j<$count1;$j++)
			{
		
				if($claimlistid==$doclist1[$j]['colorid']) 
				{
					$checked = "checked";
					break;	    		          
				}
				else 
				{
					$checked = "unchecked";
					continue;
				}
			}
			$docsubmitlist1 				.= '<input type="checkbox"  name="selected_color[]" value='.$claimlistid.' '.$checked.'>
	                                        		'.$claimlistname.''; 	
       }
	
		return $docsubmitlist1;		
	}	
	
	
	function getprojectcategory($projectcategoryid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mstprojectcategory");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($projectcategoryid)==$statelist[$i]['projectcategoryid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['projectcategoryid']."-".$statelist[$i]['projectcategoryname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['projectcategoryname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['projectcategoryid']."-".$statelist[$i]['projectcategoryname']."'>".ucwords(strtolower($statelist[$i]['projectcategoryname']))."</option>";
				}
			}
			
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	function getGalleryDetails($projectcategoryid)
   {

			$menu			=	new AllTables();

			if ($projectcategoryid!='')

			{

				$menulist		=	$menu->getInfo('',"SELECT * FROM mstprojectphotos a INNER JOIN mstprojects b ON a.projectid = b.projectid where b.projectcategoryid='$projectcategoryid' order by a.projectid");

			}

			if(is_array($menulist))
         {
         	return $menulist;
         }

	}
	
	function HeaderProjectdropdown()
	{		
			$subMenu='';
			$menu			=	new AllTables();
			$menulist		=	$menu->getInfo('',"Select * from mstprojectcategory");
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$categoryid			=		$menulist[$i]['projectcategoryid'];
							$categoryname		=		strtoupper($menulist[$i]['projectcategoryname']);

							$link					=		"projects.php?projectcategoryid=$categoryid";
							
							$subMenu				.=		'<li class="dropdown dropdown-submenu f_dropdown-submenu"><a href="'.$link.'">'.$categoryname.'</a></li>';
							
					}
					
					
					return $subMenu;
					
			}
		
	}
	
	function getAllStates($countryid ='', $stateid='')
	{
		//$states = new State();
		$all_obj = new AllTables();
		
		if($countryid != ''){
			
			$sql = "select * from mststate where countryid=".$countryid." ORDER BY StateName, StateId";
		}
		else {
			
	   	$sql = "select * from mststate ORDER BY StateName, StateId";;
	   }
	   
	   $statelist = $all_obj->getInfo('',$sql);
	   $rowcount =count($statelist);
		
		$optionvalue .= "<option value=''>Select state</option>";
		
		for($i=0;$i<$rowcount;$i++){
			
			$statename =$statelist[$i]['StateName'];
			$stateIds =$statelist[$i]['StateId'];
			
			if($stateid == $stateIds){
				
				$optionvalue .= "<option value='".$stateid."-".$statename."' selected='selected'>".$statename."</option>";
				
			}else{
			
				$optionvalue .= "<option value='".$stateid."-".$statename."'>".$statename."</option>";
			}		
		}
		
		
		return $optionvalue;
	}
	
	function getAllStateListForCombo($stateid='',$countryid='',$countryname='',$statelist='')
	{
		$rowcount = (is_array($statelist))?count($statelist):0;
		
		$strstateList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				if($stateid == $statelist[$i]['StateId'])
				{
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'" selected="selected">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
				else
				{	
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
			}
		}
		return $strstateList;	
	}
	
	function getAllStateListForComboEdit($stateid='')
	{
		$testclass    			= 	new AllTables();
		$query ="SELECT * FROM mststate";
	
		 $statelist	         = $testclass-> getInfo("",$query);
		 $rowcount  = count($statelist);
		$strstateList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				if($stateid == $statelist[$i]['StateId'])
				{
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'" selected="selected">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
				else
				{	
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
			}
		}
		return $strstateList;	
	}
	function getAllCountry()
	{
		//$states = new State();
		$all_obj = new AllTables();
	   $sql = "select * from mstcountry";
		$countrylist = $all_obj->getInfo('',$sql);
		return $countrylist;
	}
	
	function getAllCountryListForCombo1($countryid='',$countrylist='')
	{
		$rowcount = (is_array($countrylist))?count($countrylist):0;
		
		$strstateList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				if($countryid == $countrylist[$i]['countryid'])
				{
					$strstateList .= '<option value="'.$countrylist[$i]["countryid"].'-'.$countrylist[$i]["countryname"].'" selected="selected">'.ucwords(strtolower($countrylist[$i]["countryname"])).'</option>';
				}
				else
				{	
					$strstateList .= '<option value="'.$countrylist[$i]["countryid"].'-'.$countrylist[$i]["countryname"].'">'.ucwords(strtolower($countrylist[$i]["countryname"])).'</option>';
				}
			}
		}
		return $strstateList;	
	}
	
	function getprojectcombolist($projectid='')
	{
		$testclass		=	new AllTables();
		
		$statelist = $testclass->getInfo("","select * FROM mstprojects");
			
		$rowcount = count($statelist);
		
		$strstatelist = "";
		
		if ($rowcount > 0)
		{
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($projectid)==$statelist[$i]['projectid'])
				{
					$strstatelist .= "<option value='".$statelist[$i]['projectid']."-".$statelist[$i]['projectname']."' selected='selected'>".ucwords(strtolower($statelist[$i]['projectname']))."</option>";
				}
				else
				{	
					$strstatelist .= "<option value='".$statelist[$i]['projectid']."-".$statelist[$i]['projectname']."'>".ucwords(strtolower($statelist[$i]['projectname']))."</option>";
				}
			}
			
		}
		unset($testclass);
		return $strstatelist;	
	}
	
	function checkIfNullDate($dateToCheck)
	{
		$returndate='';
		if ($dateToCheck =='01-01-1970' || $dateToCheck =='0000-00-00' || $dateToCheck =='1970-01-01 00:00:00' || $dateToCheck =='0000-00-00 00:00:00' || $dateToCheck =='30-11--0001')
		{
			$returndate =null;
		}
		else 
		{
			$returndate =$dateToCheck;
		}	
		return $returndate;
	} 
	
function getProjectDetails($projectid)
{

			$menu			=	new AllTables();

			if ($projectid!='')

			{

				//$menulist		=	$menu->getInfo('',"Select * from mstprojectphotos where projectid='$projectid' ");



				$menulist		=	$menu->getInfo('',"SELECT * FROM mstprojectphotos a INNER JOIN mstprojects b ON a.projectid = b.projectid where a.projectid='$projectid'");

			}


			if(is_array($menulist))

			{

				return $menulist;

			}

	}

//-----------------format numbers--------------------------//

function format_number($strAmount)
{
	list($OrgAmount,$DotAmount)= explode('.', "$strAmount"); 		
//	list($OrgAmount,$DotAmount)= split ('[.]', $strAmount);	
//	list($OrgAmount)= split ('[.]', $strAmount);	
	
	// -- If Decimal Amount is Blank Then Make It '00 ---- ////
	
	if ($DotAmount =='')
	{
		$DotAmount ='00';
	}
	else if (strlen($DotAmount)==1)
    {
		$DotAmount .= "0"; 
    }	    
    // -- End Decimal Amount
    
    $strlength	 = strlen($OrgAmount);			// Length Of Amount 
        
    if ($strlength >'0')
    {
		if ($strlength == '1')
		{
			$a = substr($OrgAmount,"0","1");
			$strAm ="$a.$DotAmount";					
			return($strAm); 					
		}
		else if ($strlength =='2')
		{
			$a = substr($OrgAmount,"0","2");
			$strAm ="$a.$DotAmount";					
			return($strAm); 					
		}
		else if ($strlength =='3')
		{
			$a = substr($OrgAmount,"0","3");
			$strAm ="$a.$DotAmount";					
			return($strAm); 				
		}
		else if ($strlength =='4')
		{
			$b = substr($OrgAmount,"1","3");
			$a = substr($OrgAmount,"0","1");
			$strAm ="$a,$b.$DotAmount";					
			return($strAm); 		
		}
		else if ($strlength =='5')
		{
			$b = substr($OrgAmount,"2","3");
			$a = substr($OrgAmount,"0","2");
			$strAm ="$a,$b.$DotAmount";					
			return($strAm); 				
		}
		else if ($strlength =='6')
		{
			$c = substr($OrgAmount,"3","3");
			$b = substr($OrgAmount,"1","2");
			$a = substr($OrgAmount,"0","1");
			$strAm ="$a,$b,$c.$DotAmount";					
			return($strAm); 		
		}
		else if ($strlength =='7')
		{
			$c = substr($OrgAmount,"4","3");
			$b = substr($OrgAmount,"2","2");
			$a = substr($OrgAmount,"0","2");
			$strAm ="$a,$b,$c.$DotAmount";					
			return($strAm); 
							
		}
		else if ($strlength =='8')
		{
			$d = substr($OrgAmount,"5","3");
			$c = substr($OrgAmount,"3","2");
			$b = substr($OrgAmount,"1","2");
			$a = substr($OrgAmount,"0","1");
			$strAm ="$a,$b,$c,$d.$DotAmount";					
			return($strAm); 		
		}
		else if ($strlength =='9')
		{
			$d = substr($OrgAmount,"6","3");
			$c = substr($OrgAmount,"4","2");
			$b = substr($OrgAmount,"2","2");
			$a = substr($OrgAmount,"0","2");
			$strAm ="$a,$b,$c,$d.$DotAmount";					
			return($strAm); 
		}
		else if ($strlength =='10')
		{	
			$e = substr($OrgAmount,"7","3");
			$d = substr($OrgAmount,"5","2");
			$c = substr($OrgAmount,"3","2");
			$b = substr($OrgAmount,"1","2");
			$a = substr($OrgAmount,"0","1");
			
			$strAm ="$a,$b,$c,$d,$e.$DotAmount";					
			return($strAm); 
		}
		else if ($strlength =='11')
		{
			$e = substr($OrgAmount,"8","3");
			$d = substr($OrgAmount,"6","2");
			$c = substr($OrgAmount,"4","2");
			$b = substr($OrgAmount,"2","2");
			$a = substr($OrgAmount,"0","2");
			$strAm ="$a,$b,$c,$d,$e.$DotAmount";					
			return($strAm); 
		}		
	}
}
	
//echo number_to_words(11875494);
$nwords = array(  "", "One", "Two", "Three", "Four", "Five", "Six", 
	      	  "Seven", "Eight", "Nine", "Ten", "Eleven", "Twelve", "Thirteen", 
	      	  "Fourteen", "Fifteen", "Sixteen", "Seventeen", "Eighteen", 
	     	  "Nineteen", "Twenty", 30 => "Thirty", 40 => "Fourty",
                     50 => "Fifty", 60 => "Sixty", 70 => "Seventy", 80 => "Eigthy",
                     90 => "Ninety" );
function number_to_words ($x)
{
     global $nwords;
     if(!is_numeric($x))
     {
         $w = 'a';
     }
     else if(fmod($x, 1) != 0)
     {
        //$w = 'b';
			list($OrgAmount,$DotAmount)= explode('.', "$x");        
        //list($OrgAmount,$DotAmount)= preg_split('[.]', $x);
        //list($OrgAmount,$DotAmount)= split ('[.]', $x);
        if (strlen($DotAmount)==1)
        {
			$DotAmount .= "0"; 
        }
        $paise = " and paise ".number_to_words($DotAmount). " ";
        $w = number_to_words($OrgAmount);
     }
     else
     {
         if($x < 0)
         {
             $w = 'minus ';
             $x = -$x;
         }else{
             $w = '';
         }
         if($x < 21)
         {
             $w .= $nwords[$x];
         }else if($x < 100)
         {
             $w .= $nwords[10 * floor($x/10)];
             $r = fmod($x, 10);
             if($r > 0)
             {
                 $w .= ' '. $nwords[$r];
             }
         } else if($x < 1000)
         {
		
             	$w .= $nwords[floor($x/100)] .' hundred';
             $r = fmod($x, 100);
             if($r > 0)
             {
                 $w .= ' '. number_to_words($r);
             }
         } else if($x < 100000)
         {
         	$w .= number_to_words(floor($x/1000)) .' thousand';
             $r = fmod($x, 1000);
             if($r > 0)
             {
                 $w .= ' ';
                 if($r < 100)
                 {
                     $w .= ' ';
                 }
                 $w .= number_to_words($r);
             }
         } else if ($x < 10000000) {
             $w .= number_to_words(floor($x/100000)) .' Lacs';
             $r = fmod($x, 100000);
             if($r > 0)
             {
                 $w .= ' ';
                 if($r < 100)
                 {
                     $word .= ' ';
                 }
                 $w .= number_to_words($r);
             }
         }else  {
             $w .= number_to_words(floor($x/10000000)) .' Crore';
             $r = fmod($x, 10000000);
             if($r > 0)
             {
                 $w .= ' ';
                 if($r < 100)
                 {
                     $word .= ' ';
                 }
                 $w .= number_to_words($r);
             }
         }
     }
     return $w." ".$paise;
}



function CreateInvoiceContinuationNo($finrange='')
	{		
			$invoiceMenu='';
			//$financialyear = '2016-2017';
			$invoice			=	new KeyGen();
			// added by rajiv on 2nd april for invoice approval after fin year is over			
			if ($finrange=='')
			{			
				$invoicelist		=	$invoice->getKeyGen("","Select * from mstkeygen where  keygenfield = 'invoicesrno' and status = 1");
			}
			else 
			{
				$invoicelist		=	$invoice->getKeyGen("","Select * from mstkeygen where  keygenfield = 'invoicesrno' and invoiceyeardisplay = '$finrange' and status = 1");
			}		
			if(is_array($invoicelist))
			{
					$rowcount		=		count($invoicelist);
					$keygenid		=		$invoicelist[0]['keygenid'];
					$keygenvalue	=		$invoicelist[0]['keygenvalue'];
					$invoiceno 		= 		$keygenvalue + 1;
					
					$NewInvoiceNo['keygenvalue'] 		= $invoiceno;
					$wherecondition = "keygenid = ".$keygenid;
					$editkeygen = $invoice -> EditKeyGen($NewInvoiceNo,$wherecondition);
					$invoiceMenu	= $invoiceno;
			}
			return $invoiceMenu;
		
	}
	
	//Encrypt Param
	function encrParam($array){
	    if(is_array($array)){
			$arrayparam = array();
			foreach($array as $key => $value){
					$arrayparam[convert_uuencode($key)] = convert_uuencode($value);
	            //$data .= convert_uuencode($key).'~'.convert_uuencode($value).'||';
	         }						
		}
	    return $arrayparam;
	}
	
	//Decrypt param and return in array format
	function dcrParam($array){
	 	$explodeencr = explode("||", $array);
		
		for($i=0;$i<count($explodeencr)-1;$i++){
		    $param =  $explodeencr[$i];
		    
		    $explodeparam = explode("~", $param);
		   
		       
		    $arrayparam[convert_uudecode($explodeparam[0])] = convert_uudecode($explodeparam[1]);
		    //echo convert_uudecode($explodeparam[0]).'='.convert_uudecode($explodeparam[1];).'<br>';
		}
		                                                                       
		return $arrayparam;
	}
	
	function FinancialYrStartEndDates($date='')
{
	$monthtofind = ($date=='')?gmdate("n",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("n",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)));
	
	$yeartofind = ($date=='')?gmdate("Y",mktime(null,null,null,date("n"),date("d"),date("Y"))):gmdate("Y",mktime(null,null,null,substr($date,0,2),substr($date,3,2),substr($date,6,4)))-$noofyearsback;
	
		if ($monthtofind < 4)
		{
			// jan feb or march month so deduct one from current year
			$FnYear = ($yeartofind-1);
			$FinancialYear = $FnYear.'-04-01'."|".$yeartofind.'-03-31';  
		}
		else
		{
			$FnYear = ($yeartofind+1);
			$FinancialYear = $yeartofind.'-04-01'."|".$FnYear.'-03-31';
		}
		
		return $FinancialYear;	
}

function formatdate($date1,$dateformat="d-m-Y")
{
	
	$string = $date1; 	
	if ($string > "1900-12-30")
	{
	
		$string = $date1; 	
		$stringArray = explode("-", $string); 
		$date = mktime(0,0,0,$stringArray[1],$stringArray[2],$stringArray[0]); 

		$converteddate = date($dateformat, $date); 
		return ($converteddate);    	 
	}
}	
function getAllStateListForComboForSearch($countryid='',$stateid='')
	{
		$state = new State();
		//$panelid = '';
		$statelist = $state->getState("","select * from mststate where countryid = $countryid ORDER BY StateId");
		
		$rowcount = count($statelist);
		
		$strstateList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				if(strtoupper($stateid)==$statelist[$i]['StateId'])
				{
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'" selected="selected">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
				else
				{	
					$strstateList .= '<option value="'.$statelist[$i]["StateId"].'-'.$statelist[$i]["StateName"].'">'.ucwords(strtolower($statelist[$i]["StateName"])).'</option>';
				}
			}
		}
		return $strstateList;	
	}	
	function getAllCountryListForCombo($GCountry='')
	{
		$conuntries = new State();
		
		$countrylist = $conuntries->getState("","select * from mstcountry");
		
		$rowcount = count($countrylist);
		
		$strCountryList = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				
				if(strtolower($GCountry) == strtolower($countrylist[$i]['countryname']))
				{
					$strCountryList .= '<option value="'.$countrylist[$i]["countryid"].'-'.$countrylist[$i]["countryname"].'" selected="selected">'.ucwords(strtolower($countrylist[$i]["countryname"])).'</option>';
				}
				else
				{	
					$strCountryList .= '<option value="'.$countrylist[$i]["countryid"].'-'.$countrylist[$i]["countryname"].'">'.ucwords(strtolower($countrylist[$i]["countryname"])).'</option>';
				}
			}
		}
		return $strCountryList;	
	}	
	
	function getStateNameORId($stateid='',$statename='')
	{
		$state = new State();
		if($stateid != '')
		{
			$sql = "select * from mststate where StateId = $stateid ";
			$statelist = $state->getState("",$sql);
			$strStateList 	= $statelist[0]['StateName'];
			
		}
		elseif($statename != '')
		{
			$sql = "select * from mststate where StateName = '".$statename."' ";
			$statelist = $state->getState("",$sql);
			$strStateList 	= $statelist[0]['StateId'];
		}
		return $strStateList;	
	}	
	
	function getAllUnits($unit='')
	{
		$units = new AllTables();
		
		$unitlist = $units->getInfo("","select * from product_units");
		
		$rowcount = count($unitlist);
		
		$strunitlist = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				
				if(strtolower($unit) == strtolower($unitlist[$i]['unitid']))
				{
					$strunitlist .= '<option value="'.$unitlist[$i]["unitid"].'-'.$unitlist[$i]["unitname"].'" selected="selected">'.ucwords(strtolower($unitlist[$i]["unitname"])).'</option>';
				}
				else
				{	
					$strunitlist .= '<option value="'.$unitlist[$i]["unitid"].'-'.$unitlist[$i]["unitname"].'">'.ucwords(strtolower($unitlist[$i]["unitname"])).'</option>';
				}
			}
		}
		return $strunitlist;	
	}	
	
	
	function getAllCompanyList($membercompanyid='',$memberid='')
	{
		$units = new AllTables();
		
		$unitlist = $units->getInfo("","select * from user_company where memberid = $memberid");
		
		$rowcount = count($unitlist);
		
		$strunitlist = "";
		
		if ($rowcount > 0)
		{
			
			for($i=0;$i<$rowcount;$i++) 
			{	
				
				if(strtolower($membercompanyid) == strtolower($unitlist[$i]['membercompanyid']))
				{
					$strunitlist .= '<option value="'.$unitlist[$i]["membercompanyid"].'" selected="selected">'.ucwords(strtolower($unitlist[$i]["companyname"])).'</option>';
				}
				else
				{	
					$strunitlist .= '<option value="'.$unitlist[$i]["membercompanyid"].'">'.ucwords(strtolower($unitlist[$i]["companyname"])).'</option>';
				}
			}
		}
		return $strunitlist;	
	}	
	
	
	function getMyCompanyFactoryList($companyid='')
	{
			$menu			=	new Factories();
		$sql="Select * from member_factories where companyid=$companyid";
			$menulist		=	$menu->getFactories('',$sql);
			//print_r($menulist);
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$factory =$menulist[$i]['factoryaddress'];
							$memberfactoryid =$menulist[$i]['memberfactoryid'];
			
 							$factoryaddress				.=	'<tbody>';
							$factoryaddress				.=	 '<tr>';
							$factoryaddress				.=	'<td>'.$factory.'</td>';
							$factoryaddress				.=	'<td><a href="edit-mycompany-factories.php?memberfactoryid='.$memberfactoryid.'">Edit</a></td>';
							$factoryaddress				.=	'</tr>';
							 $factoryaddress				.=	'</tbody>';
							
							
					}
					
					
			}
			return $factoryaddress;
	}
	
		function getMyCompanyBranchList($companyid='')
	{
			$menu			=	new Branches();
		$sql="Select * from member_branches where companyid=$companyid";
			$menulist		=	$menu->getBranches('',$sql);
			//print_r($menulist);
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$branch =$menulist[$i]['branchaddress'];
							$memberbranchid =$menulist[$i]['memberbranchid'];
			
 							$branchaddress				.=	'<tbody>';
							$branchaddress				.=	 '<tr>';
							$branchaddress				.=	'<td>'.$branch.'</td>';
							$branchaddress				.=	'<td><a href="edit-mycompany-branches.php?memberbranchid='.$memberbranchid.'">Edit</a></td>';
							$branchaddress				.=	'</tr>';
							 $branchaddress				.=	'</tbody>';
							
							
					}
					
					
			}
			return $branchaddress;
	}
	
	function getClientFactoryList($companyid='')
	{
			$menu			=	new ClientFactories();
		$sql="Select * from client_factories where clientcompanyid=$companyid";
			$menulist		=	$menu->getClientFactories('',$sql);
			//print_r($menulist);
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$factory =$menulist[$i]['factoryaddress'];
							$clientfactoryid =$menulist[$i]['clientfactoryid'];
			
 							$factoryaddress				.=	'<tbody>';
							$factoryaddress				.=	 '<tr>';
							$factoryaddress				.=	'<td>'.$factory.'</td>';
							$factoryaddress				.=	'<td><a href="edit-client-factories.php?clientfactoryid='.$clientfactoryid.'">Edit</a></td>';
							$factoryaddress				.=	'</tr>';
							 $factoryaddress				.=	'</tbody>';
							
							
					}
					
					
			}
			return $factoryaddress;
	}

	
		function getClientBranchList($companyid='')
	{
			$menu			=	new ClientBranches();
		$sql="Select * from client_branches where clientcompanyid=$companyid";
			$menulist		=	$menu->getClientBranches('',$sql);
			//print_r($menulist);
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$branch =$menulist[$i]['branchaddress'];
							$clientbranchid =$menulist[$i]['clientbranchid'];
			
 							$branchaddress				.=	'<tbody>';
							$branchaddress				.=	 '<tr>';
							$branchaddress				.=	'<td>'.$branch.'</td>';
							$branchaddress				.=	'<td><a href="edit-client-branches.php?clientbranchid='.$clientbranchid.'">Edit</a></td>';
							$branchaddress				.=	'</tr>';
							 $branchaddress				.=	'</tbody>';
							
							
					}
					
					
			}
			return $branchaddress;
	}
	
	//Function used for factory display in panel
function FactoryDisplay($companyid='')
	{		
			//$accessid = 2;
		
			$factoryMenu='';
			$factory			=	new ClientFactories();
	$factorylist		=	$factory->getClientFactories("","Select * from client_factories where isdeleted =0 and clientcompanyid=$companyid");
	//print_r($factorylist);
			//if(is_array($factorylist))
			//{
					$rowcount			=		count($factorylist);
					for($i=0;$i<$rowcount;$i++)
					{
							$companyid				=		$factorylist[$i]['clientcompanyid'];
							$clientfactoryid		=		$factorylist[$i]['clientfactoryid'];
							$factoryaddress		=		$factorylist[$i]['factoryaddress'];
							$factoryaddressline1	=		$factorylist[$i]['factoryaddressline1'];
							$factoryaddressline2	=		$factorylist[$i]['factoryaddressline2'];
							$factoryaddressline3	=		$factorylist[$i]['factoryaddressline3'];
							$factoryaddressline4	=		$factorylist[$i]['factoryaddressline4'];
							$factorystreet			= 		$factorylist[$i]['factorystreet'];
							$factorycity			=		$factorylist[$i]['factorycity'];	
							$factorycountry			=		$factorylist[$i]['factorycountry'];
							$factorypincode		=		$factorylist[$i]['factorypincode'];
							//$factorystateid		= 		$factorylist[$i]['factorystateid'];							
							//$factorystate			= 		$factorylist[$i]['factorystate'];
							//$factorytelno			=		$factorylist[$i]['factorytelno'];
							//$factoryfaxno			= 		$factorylist[$i]['factoryfaxno'];
							//$factoryemail			=		$factorylist[$i]['factoryemail'];
							$factorygstno			=		$factorylist[$i]['factorygstno'];
							$factorystate			= 		$factorylist[$i]['factorystate'];
	 		$factory_Stateid1								= $factorylist[$i]['factory_Stateid1'];
						$factory_StateidName							= $factorylist[$i]['factory_StateidName'];
						$GCountry									= $factorylist[$i]['txtfactorycountry'];
							
							$formid 					= 		"'fact_reg_form_".$clientfactoryid."'";
							$sendurl					=		"'submit.php'";
							$deleteurl				=		"'delete_factory.php'";
							
							

								$editable_grid = '<a href="#" class="btn btn-space btn-light fact_edit fact_span_'.$clientfactoryid.'" rel="'.$clientfactoryid.'" id="fact_edit_'.$clientfactoryid.'" onclick="return false;">EDIT</a>
															<a href="#" class="btn btn-space btn-primary fact_cancel fact_text_'.$clientfactoryid.'" rel="'.$clientfactoryid.'" id="fact_cancel_'.$clientfactoryid.'" onclick="return false;" style="display:none;">CANCEL</a>
															<a href="#" class="btn btn-space btn-secondary fact_save fact_text_'.$clientfactoryid.'" rel="'.$clientfactoryid.'" id="fact_save'.$clientfactoryid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>
															<a href="#" class="btn btn-space btn-danger fact_delete fact_text_'.$clientfactoryid.'" rel="'.$clientfactoryid.'" id="fact_delete'.$clientfactoryid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>';

	
															
				$factoryMenu.=	'<div class="row">
				<div class="col-lg-6" id="single_factory_'.$clientfactoryid.'">
									<div class="card">
				<div class="card-body" id="factory_panel_'.$clientfactoryid.'">
					<div id="form_content_'.$clientfactoryid.'">
							<form id="fact_reg_form_'.$clientfactoryid.'">
								<input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
									<input type="hidden" id="txtcompanyid_'.$companyid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtclientfactoryid_'.$clientfactoryid.'" name="txtclientfactoryid" value="'.$clientfactoryid.'" class="form-control">
									<input type="hidden" id="operation_'.$clientfactoryid.'" name="operation" value="edit_factory" class="form-control">
			<!--<div class="form-group">
					<label><b>Address : </b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factoryaddress.'</div>
					<textarea readonly id="txtfactoryaddress_'.$clientfactoryid.'" name="txtfactoryaddress" class="form-control fact_text_'.$clientfactoryid.'" rows="3" style="display:none;">'.$factoryaddress.'</textarea>
				</div>-->
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factoryaddressline1.'</div>
					<input type="text" id="txtfactoryaddressline1_'.$clientfactoryid.'" name="txtfactoryaddressline1"  value="'.$factoryaddressline1.'" class="form-control fact_text_'.$clientfactoryid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factoryaddressline2.'</div>
					<input type="text" id="txtfactoryaddressline2_'.$clientfactoryid.'" name="txtfactoryaddressline2"  value="'.$factoryaddressline2.'" class="form-control fact_text_'.$clientfactoryid.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factorycity.'</div>
					<input type="text" id="txtfactorycity_'.$clientfactoryid.'" name="txtfactorycity"  value="'.$factorycity.'" class="form-control fact_text_'.$clientfactoryid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factorypincode.'</div>
					<input type="text" id="txtfactorypincode_'.$clientfactoryid.'" name="txtfactorypincode" value="'.$factorypincode.'" class="form-control fact_text_'.$clientfactoryid.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factorycountry.'</div>
               <select id="txtfactorycountry_'.$clientfactoryid.'" name="txtfactorycountry" class="form-control fact_text_'.$clientfactoryid.'"  getState(this.value,'.$factory_StateidName.'); style="display:none;">
						<option value="">Select Country</option>
	'.getAllCountryListForCombo($factorycountry).'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factory_StateidName.'</div>
               <select id="txtstate_'.$clientfactoryid.'" name="txtstate" class="form-control fact_text_'.$clientfactoryid.'"  style="display:none;">
						<option value="" >Select State</option>
						'.getAllStateListForComboEdit($factory_Stateid1).'
					</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>GST No</b></label>
					<div class="fact_span_'.$clientfactoryid.'">'.$factorygstno.'</div>
					<input type="text" id="txtfactorygstno_'.$clientfactoryid.'" name="txtfactorygstno"  value="'.$factorygstno.'" class="form-control fact_text_'.$clientfactoryid.'" style="display:none;">
				</div>
						
							</div>
						
													
									</form>'.$editable_grid.'
									</div>
										</div>
										</div>
										</div>
										</div>';																
		}
					
					
					return $factoryMenu;
					
			//}
}


	//Function used for branch display in panel, 
	function BranchesDisplay($companyid='')
	{		
			
			$branchMenu='';
			$branch			=	new ClientBranches();
	
			$branchlist		=	$branch->getClientBranches("","Select * from client_branches where isdeleted =0 and  clientcompanyid=$companyid");
			//print_r($branchlist);
			if(is_array($branchlist))
			{
					$rowcount			=		count($branchlist);
					for($i=0;$i<$rowcount;$i++)
					{
									$companyid				=		$branchlist[$i]['clientcompanyid'];
							$clientbranchid		=		$branchlist[$i]['clientbranchid'];
							$branchaddress			=		$branchlist[$i]['branchaddress'];
							$branchaddressline1	=		$branchlist[$i]['branchaddressline1'];
							$branchaddressline2	=		$branchlist[$i]['branchaddressline2'];
							$branchaddressline3	=		$branchlist[$i]['branchaddressline3'];
							$branchaddressline4	=		$branchlist[$i]['branchaddressline4'];
							$branchstreet			= 		$branchlist[$i]['branchstreet'];
							$branchcity				=		$branchlist[$i]['branchcity'];	
							$branchpincode			=		$branchlist[$i]['branchpincode'];
						//	$branchstateid			= 		$branchlist[$i]['branchstateid'];
						//	$branchstate			= 		$branchlist[$i]['branchstate'];
						//	$branchtelno			=		$branchlist[$i]['branchtelno'];
							////$branchfaxno			= 		$branchlist[$i]['branchfaxno'];
					 $branchcountry 			=		$branchlist[$i]['branchcountry'];
							$branchgstno			=		$branchlist[$i]['branchgstno'];

							$branchstate			= 		$branchlist[$i]['branchstate'];
	 						$branch_Stateid1								= $branchlist[$i]['branch_stateid1'];
						$branch_StateidName							= $branchlist[$i]['branch_StateidName'];
						$GCountry									= $branchlist[$i]['txtbranchcountry'];
						$branchaddressfordiv			=		$branchaddress."<br> ".$branchcity."<br> ".$branch_StateidName."<br> ".$branchcountry."-".$branchpincode;
						$branchaddressfortextarea			=		$branchaddress." ".$branchcity." ".$branch_StateidName." ".$branchcountry."-".$branchpincode;
							
							$formid 					= 		"'branch_reg_form_".$clientbranchid."'";
							$sendurl					=		"'branch_submit.php'";
							$deleteurl					=		"'delete_branch.php'";
					//print_r($branchlist);
													$editable_grid = '<a href="#" class="btn btn-space btn-light branch_edit branch_span_'.$clientbranchid.'" rel="'.$clientbranchid.'" id="branch_edit_'.$clientbranchid.'" onclick="return false;">EDIT</a>
														<a href="#" class="btn btn-space btn-primary branch_cancel branch_text_'.$clientbranchid.'" rel="'.$clientbranchid.'" id="branch_cancel_'.$clientbranchid.'" onclick="return false;" style="display:none;">CANCEL</a>
														<a href="#" class="btn btn-space btn-secondary branch_save branch_text_'.$clientbranchid.'" rel="'.$clientbranchid.'" id="branch_save_'.$clientbranchid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>
														<a href="#" class="btn btn-space btn-danger branch_delete branch_text_'.$clientbranchid.'" rel="'.$clientbranchid.'" id="branch_delete_'.$clientbranchid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>';
						
							$branchMenu				.=	'<div class="row">
																<div class="col-lg-6"  id="single_branch_'.$clientbranchid.'">	 									
																	<div class="card">
																			<div class="card-body" id="branch_panel_'.$clientbranchid.'">											
																				<div id="form_content_branch_'.$clientbranchid.'">
																				
																					<form id="branch_reg_form_'.$clientbranchid.'">
																					   <input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
																						<input type="hidden" id="txtcompanyid_'.$clientbranchid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
																						<input type="hidden" id="txtclientbranchid_'.$clientbranchid.'" name="txtclientbranchid" value="'.$clientbranchid.'" class="form-control">
																						<input type="hidden" id="operation_branch_'.$clientbranchid.'" name="operation_branch" value="edit_branch" class="form-control">
																						<!--<div class="form-group">
																							<label><b>Address : </b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchaddressfordiv.'</div>
																							<textarea readonly id="txtbranchaddress_'.$clientbranchid.'" name="txtbranchaddress" class="form-control branch_text_'.$clientbranchid.'" rows="3" style="display:none;">'.$branchaddressfortextarea.'</textarea>
																						</div>-->
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>Address Line 1</b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchaddressline1.'</div>
																							<input type="text" id="txtbranchaddressline1_'.$clientbranchid.'" name="txtbranchaddressline1"  value="'.$branchaddressline1.'" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																						</div>
																						<div class="form-group col-md-6">
																							<label><b>Address Line 2</b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchaddressline2.'</div>
																							<input type="text" id="txtbranchaddressline2_'.$clientbranchid.'" name="txtbranchaddressline2"  value="'.$branchaddressline2.'" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																						</div>
																					</div>
																					
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>City</b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchcity.'</div>
																							<input type="text" id="txtbranchcity_'.$clientbranchid.'" name="txtbranchcity"  value="'.$branchcity.'" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																						</div>
																						<div class="form-group col-md-6">
																							<label><b>Pin Code</b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchpincode.'</div>
																							<input type="text" id="txtbranchpincode_'.$clientbranchid.'" name="txtbranchpincode" value="'.$branchpincode.'" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																						</div>
																						</div>
																						<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>Country</b></label>
																								<div class="branch_span_'.$clientbranchid.'">'.$branchcountry.'</div>
																			               <select id="txtbranchcountry_'.$clientbranchid.'" name="txtbranchcountry" class="form-control branch_text_'.$clientbranchid.'"  getState(this.value,'.$branch_StateidName.'); style="display:none;">
																													<option value="">Select Country</option>
																								'.getAllCountryListForCombo($branchcountry).'
																								</select>
																							</div>
																							<div class="form-group col-md-6">
																							<label><b>State</b></label>
																								<div class="branch_span_'.$clientbranchid.'">'.$branch_StateidName.'</div>
																			               <select id="txtbranchstate_'.$clientbranchid.'" name="txtbranchstate" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																									<option value="" selected>Select State</option>
																									'.getAllStateListForComboEdit($branch_Stateid1).'
																								</select>
																							</div>
																						</div>
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>GST No</b></label>
																							<div class="branch_span_'.$clientbranchid.'">'.$branchgstno.'</div>
																							<input type="text" id="txtbranchgstno_'.$clientbranchid.'" name="txtbranchgstno" value="'.$branchgstno.'" class="form-control branch_text_'.$clientbranchid.'" style="display:none;">
																						</div>
																						</div>
																						</form>'.$editable_grid.'
																				
																				</div>													
																			</div>
																			</div>
																  	</div>
															</div>';
					}
					
					
					
					
			}
			return $branchMenu;
		
	}
	
	
	//Function used for Client details display in panel
function ClientDetailsDisplay($companyid='')
	{		
			
		
			$clientMenu='';
			$client			=	new Client();
	$sqllist		=	$client->getClient("","","select * from mstclients where clientcompanyid = $companyid ");
	//print_r($sqllist);
			//if(is_array($factorylist))
			//{
					 $rowcount			=		count($sqllist);
				for($i=0;$i<$rowcount;$i++)
	{
		$companyname 								= $sqllist[$i]['companyname'];
 	    $memberid											 = $sqllist[$i]['memberid'];
		$clientcompanyid							= $sqllist[$i]['clientcompanyid'];
		$Addline1									= $sqllist[$i]['Addline1'];
		$Addline2									= $sqllist[$i]['Addline2'];
		$head_CityName								= $sqllist[$i]['head_CityName'];
		$gstno 		   = $sqllist[$i]['gstno'];
		$panno 	      = $sqllist[$i]['panno'];
		$Tan_No 	      = $sqllist[$i]['Tan_No'];
		$head_TelNo	   = $sqllist[$i]['head_TelNo'];
		$head_mobNo	   = $sqllist[$i]['head_mobNo'];
		$head_FaxNo	   = $sqllist[$i]['head_FaxNo'];
		$head_Email	   = $sqllist[$i]['head_Email'];
	   $PersonName1   = $sqllist[$i]['PersonName1'];
		$gstapplicable = $sqllist[$i]['gstapplicable'];
		$head_Pin      = $sqllist[$i]['head_Pin'];
		$Country  									=$sqllist[$i]['Country'];
		$head_TelNo    = $sqllist[$i]['head_TelNo'];
		$Address	 	   =	$sqllist[$i]['Addline1']."<br>".$sqllist[$i]['Addline2']."<br>".$sqllist[$i]['head_CityName']."<br>".$sqllist[$i]['head_StateidName']."-".$sqllist[$i]['head_Pin']."<br>".$sqllist[$i]['Country'];
		$Addressfortextarea	 	   =	$sqllist[$i]['Addline1']." ".$sqllist[$i]['Addline2']." ".$sqllist[$i]['head_CityName']." ".$sqllist[$i]['head_StateidName']."-".$sqllist[$i]['head_Pin']." ".$sqllist[$i]['Country'];
				
		$status		   = $sqllist[$i]['memberapprovalstatus'];
		 $memberapprovalstatus					= $sqllist[$i]['memberapprovalstatus'];
		      if($memberapprovalstatus == '1')
		      {
					$valselect1      = "selected";
		      }
		      elseif($memberapprovalstatus == '0')
		      {
					$valselect0      = "selected";
		      }
		       if($status == '1') {
		      	$status1 ="Active";
		      }
		       else if($status == '0') {
		      	$status1 ="Inactive";
		      }
		       if($gstapplicable == '1') {
		      	$gstapplicable1 ="GST applicable/ invoice";
		      	$gstvalselect1 = "selected";
		      	
		      }
		       else if($gstapplicable == '0') {
		      	$gstapplicable1 ="GST applicable/  Product";
		      	$gstvalselect0 = "selected";
		      }
		       else if($gstapplicable == '2') {
		      	$gstapplicable1 ="GST Not applicable";
		      	$gstvalselect2 = "selected";
		      }
		      
		      

	
	 		$head_Stateid1								= $sqllist[$i]['head_Stateid1'];
		  $head_StateidName							= $sqllist[$i]['head_StateidName'];
			$GCountry									= $branchlist[$i]['txtcountry'];
							$formid 					= 		"'client_reg_form_".$clientcompanyid."'";
							$sendurl					=		"'client_details_submit.php'";
							//$deleteurl				=		"'delete_client_details.php'";
							
							

								$editable_grid = '<a href="#" class="btn btn-space btn-light client_edit client_span_'.$clientcompanyid.'" rel="'.$clientcompanyid.'" id="client_edit_'.$clientcompanyid.'" onclick="return false;">EDIT</a>
															<a href="#" class="btn btn-space btn-primary client_cancel client_text_'.$clientcompanyid.'" rel="'.$clientcompanyid.'" id="client_cancel_'.$clientcompanyid.'" onclick="return false;" style="display:none;">CANCEL</a>
															<a href="#" class="btn btn-space btn-secondary client_save client_text_'.$clientcompanyid.'" rel="'.$clientcompanyid.'" id="client_save'.$clientcompanyid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>';

	
															
				$clientMenu.=	'<div class="row">
				<div class="col-lg-6 client-details" id="single_client_'.$clientcompanyid.'">
									<div class="card">
				<div class="card-body" id="client_panel_'.$clientcompanyid.'">
					<div id="form_content_client_'.$clientcompanyid.'">
							<form id="client_reg_form_'.$clientcompanyid.'">
								<input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
									<input type="hidden" id="txtcompanyid_'.$clientcompanyid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtmemberid_'.$clientcompanyid.'" name="txtmemberid" value="'.$memberid.'" class="form-control">
									<input type="hidden" id="txtclientcompanyid_'.$clientcompanyid.'" name="txtclientcompanyid" value="'.$clientcompanyid.'" class="form-control">
									<input type="hidden" id="operation_client_'.$clientcompanyid.'" name="operation_client" value="edit_client" class="form-control">
				<!--<div class="form-group">
					<label><b>Address : </b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$Address.'</div>
					<textarea readonly id="txtaddress_'.$clientcompanyid.'" name="txtaddress" class="form-control client_text_'.$clientcompanyid.'" rows="3" style="display:none;">'.$Addressfortextarea.'</textarea>
				</div>-->
				<div class="row">
				<div class="form-group col-md-6">
					<label><b>Company Name</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$companyname.'</div>
					<input type="text" id="txtcompanyname_'.$clientcompanyid.'" name="txtcompanyname"  value="'.$companyname.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				
				</div>
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$Addline1.'</div>
					<input type="text" id="txtaddressline1_'.$clientcompanyid.'" name="txtaddressline1"  value="'.$Addline1.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$Addline2.'</div>
					<input type="text" id="txtaddressline2_'.$clientcompanyid.'" name="txtaddressline2"  value="'.$Addline2.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_CityName.'</div>
					<input type="text" id="txthead_CityName1_'.$clientcompanyid.'" name="txthead_CityName1"  value="'.$head_CityName.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_Pin.'</div>
					<input type="text" id="txtpincode1_'.$clientcompanyid.'" name="txtpincode1" value="'.$head_Pin.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$Country.'</div>
               <select id="txtcountry_'.$clientcompanyid.'" name="txtcountry" class="form-control client_text_'.$clientcompanyid.'"  getState(this.value,'.$head_StateidName.'); style="display:none;">
						<option value="">Select Country</option>
	'.getAllCountryListForCombo($Country).'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_StateidName.'</div>
               <select id="txtstate_'.$clientcompanyid.'" name="txtstate" class="form-control client_text_'.$clientcompanyid.'"  style="display:none;">
						<option value="" >Select State</option>
						'.getAllStateListForComboEdit($head_Stateid1).'
					</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Contact Person Name</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$PersonName1.'</div>
					<input type="text" id="txtclientname_'.$clientcompanyid.'" name="txtclientname"  value="'.$PersonName1.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Phone Number</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_TelNo.'</div>
					<input type="text" id="txthead_TelNo_'.$clientcompanyid.'" name="txthead_TelNo"  value="'.$head_TelNo.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Mobile Number </b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_mobNo.'</div>
					<input type="text" id="head_mobNo_'.$clientcompanyid.'" name="head_mobNo"  value="'.$head_mobNo.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Email Address</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$head_Email.'</div>
					<input type="email" id="head_Email_'.$clientcompanyid.'" name="head_Email"  value="'.$head_Email.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				</div>
				
					<div class="row">
			<div class="form-group col-md-6">
					<label><b>Active/Inactive State</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$status1.'</div>
					<select  id="input-select" name="txtstatus" class="form-control client_text_'.$clientcompanyid.'"  style="display:none;">
							<option value="1"'.$valselect1.'>Active</option>
							<option value="0"'.$valselect0.'>Inactive</option>
						
							</select>
				</div>
				<div class="form-group col-md-6">
					<label><b>GST applicatble</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$gstapplicable1.'</div>
					<select  id="input-select" name="txtgstapplicable" class="form-control client_text_'.$clientcompanyid.'"  style="display:none;">
							<option value="0" '.$gstvalselect0.'>GST applicable/ Product</option>
							<option value="1" '.$gstvalselect1.' >GST applicatble/invoice</option>
							<option value="2" '.$gstvalselect2.'>GST Not applicatble</option>
							</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>GST No</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$gstno.'</div>
					<input type="text" id="txtgstno1_'.$clientcompanyid.'" name="txtgstno1"  value="'.$gstno.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Company PAN NO.</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$panno.'</div>
					<input type="text" id="txtpanno_'.$clientcompanyid.'" name="txtpanno"  value="'.$panno.'" class="form-control client_text_'.$clientcompanyid.'" onchange="ValidatePAN()" style="display:none;">
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Company TAN NO.</b></label>
					<div class="client_span_'.$clientcompanyid.'">'.$Tan_No.'</div>
					<input type="text" id="txttanno_'.$clientcompanyid.'" name="txttanno"  value="'.$Tan_No.'" class="form-control client_text_'.$clientcompanyid.'" style="display:none;">
				</div>	
					</div>			
						
													
									</form>'.$editable_grid.'
									</div>
										</div>
										</div>
										</div>
										</div>';																
		}
					
					
					return $clientMenu;
					
			//}
}

	//Function used for Company details display in panel
function CompanyDetailsDisplay($companyid='')
	{		
			
		
			$companyMenu='';
			$company			=	new Company();
		
	$sqllist	=$company->getCompany("","","select * from user_company where membercompanyid = $companyid");
	//print_r($sqllist);
			//if(is_array($factorylist))
			//{
					 $rowcount			=		count($sqllist);
				for($i=0;$i<$rowcount;$i++)
	{
		$companyname 								= $sqllist[$i]['companyname'];
 	    $memberid									= $sqllist[$i]['memberid'];
		$membercompanyid							= $sqllist[$i]['membercompanyid'];
		$Addline1									= $sqllist[$i]['Addline1'];
		$Addline2									= $sqllist[$i]['Addline2'];
		$head_CityName								= $sqllist[$i]['head_CityName'];
		$gstno 		   = $sqllist[$i]['gstno'];
		$panno 	      = $sqllist[$i]['panno'];
		$Tan_No 	      = $sqllist[$i]['Tan_No'];
		$head_TelNo	   = $sqllist[$i]['head_TelNo'];
		$head_mobNo	   = $sqllist[$i]['head_mobNo'];
		$head_FaxNo	   = $sqllist[$i]['head_FaxNo'];
		$head_Email	   = $sqllist[$i]['head_Email'];
	   $PersonName1   = $sqllist[$i]['comp_contact_personname'];
		$gstapplicable = $sqllist[$i]['gstapplicable'];
		$head_Pin      = $sqllist[$i]['head_Pin'];
	   $Country  		= $sqllist[$i]['Country'];
		$head_TelNo    = $sqllist[$i]['head_TelNo'];

		$BankName = $sqllist[$i]['Bankname'];
		$Bank_ACno      = $sqllist[$i]['BankAC'];
	   $Branch  		= $sqllist[$i]['Branch'];
		$IFSC_Code    = $sqllist[$i]['IFSC_Code'];

		$Address	 	   =	$sqllist[$i]['Addline1']."<br>".$sqllist[$i]['Addline2']."<br>".$sqllist[$i]['head_CityName']."<br>".$sqllist[$i]['head_StateidName'].'-'.$sqllist[$i]['head_Pin']."<br>".$sqllist[$i]['Country'];
		$status		   = $sqllist[$i]['memberapprovalstatus'];
		 $memberapprovalstatus					= $sqllist[$i]['memberapprovalstatus'];
		      if($memberapprovalstatus == '1')
		      {
					$valselect1      = "selected";
		      }
		      elseif($memberapprovalstatus == '0')
		      {
					$valselect0      = "selected";
		      }
		       if($status == '1') {
		      	$status1 ="Active";
		      }
		       else if($status == '0') {
		      	$status1 ="Inactive";
		      }
		       if($gstapplicable == '1') {
		      	$gstapplicable1 ="GST applicable/ invoice";
		      }
		       else if($gstapplicable == '0') {
		      	$gstapplicable1 ="GST applicable/  Product";
		      }
		      
		   $head_Stateid1								= $sqllist[$i]['head_Stateid1'];
		   $head_StateidName							= $sqllist[$i]['head_StateidName'];
			
			$selected_country 						= getAllCountryListForCombo($Country); 
	//		$selected_state  							=	getAllStateListForComboEdit($head_Stateid1);
			$upload_logo								= GALLERY_PHOTO_THUMB_PATH.$sqllist[$i]['upload_logo'];
			$upload_header								= GALLERY_PHOTO_THUMB_PATH.$sqllist[$i]['upload_header'];
			$upload_logo1								= $sqllist[$i]['upload_logo'];
			$upload_header1							= $sqllist[$i]['upload_header'];
			$variable_tocallfunction 				= getState($Country,$head_Stateid1);
	 		
							$formid 					= 		"'company_reg_form_".$membercompanyid."'";
							$sendurl					=		"'company_details_submit.php'";
							//$deleteurl				=		"'delete_company_details.php'";
							
							

								$editable_grid = '<a href="#" class="btn btn-space btn-light company_edit company_span_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="company_edit_'.$membercompanyid.'" onclick="return false;">EDIT</a>
															<a href="#" class="btn btn-space btn-primary company_cancel company_text_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="company_cancel_'.$membercompanyid.'" onclick="return false;" style="display:none;">CANCEL</a>
															<a href="#" class="btn btn-space btn-secondary company_save company_text_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="company_save_'.$membercompanyid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>


															';

	  if ($upload_logo1=="")
	  {
	  	 	$upload_logo_var = '<a href="#" id="fileToUpload" name="fileToUpload" class="form-control company_text_'.$membercompanyid.'" style="display:none;">Upload Logo</a>';
	  }
	  else if ($upload_logo1 !="")
	  {
	  		$upload_logo_var = '<a href="#" id="fileToUpload" name="fileToUpload" class="form-control company_text_'.$membercompanyid.'" style="display:none;">Change Logo</a>';
	   }
	   
	  if ($upload_header1=="")
	  {
	  	 	$upload_header_var = '<a href="#" id="fileToUpload1" name="fileToUpload1" class="form-control company_text_'.$membercompanyid.'" style="display:none;">Upload Header</a>';
	  }
	  else if ($upload_header1 !="")
	  {
	  		$upload_header_var = '<a href="#" id="fileToUpload1" name="fileToUpload1" class="form-control company_text_'.$membercompanyid.'" style="display:none;">Change Header</a> <br> 
	  									 <a href="#" id="CancelUploadedHeader" name="CancelUploadedHeader" class="form-control company_text_'.$membercompanyid.'" style="display:none;">Remove Header</a>';
	  }
		// &nbsp;&nbsp;&nbsp;<a href="#" id="CancelUploadedImage" name="CancelUploadedImage">Remove Logo</a>
	  
															
				$companyMenu.=	'<form id="company_reg_form_'.$membercompanyid.'">
				<div class="row">
				<div class="col-lg-6 company-details" id="single_company_'.$membercompanyid.'">
									<div class="card">
				<div class="card-body" id="company_panel_'.$membercompanyid.'">
					<div id="form_content_company_'.$membercompanyid.'">
						
								<input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
									<input type="hidden" id="txtcompanyid_'.$membercompanyid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtmemberid_'.$membercompanyid.'" name="txtmemberid" value="'.$memberid.'" class="form-control">
									<input type="hidden" id="txtmembercompanyid_'.$membercompanyid.'" name="txtmembercompanyid" value="'.$membercompanyid.'" class="form-control">
									<input type="hidden" id="operation_company_'.$membercompanyid.'" name="operation_company" value="edit_company" class="form-control">
			<!-- <div class="form-group">
					<label><b>Address : </b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Address.'</div>
					<textarea readonly id="txtaddress_'.$membercompanyid.'" name="txtaddress" class="form-control company_text_'.$membercompanyid.'" rows="3" style="display:none;">'.$Address.'</textarea>
				</div>  -->
				<div class="row">
				<div class="form-group col-md-6">
					<label><b>Company Name</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$companyname.'</div>
					<input type="text" id="txtcompanyname_'.$membercompanyid.'" name="txtcompanyname"  value="'.$companyname.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				
				</div>
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Addline1.'</div>
					<input type="text" id="txtaddressline1_'.$membercompanyid.'" name="txtaddressline1"  value="'.$Addline1.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Addline2.'</div>
					<input type="text" id="txtaddressline2_'.$membercompanyid.'" name="txtaddressline2"  value="'.$Addline2.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_CityName.'</div>
					<input type="text" id="txthead_CityName1_'.$membercompanyid.'" name="txthead_CityName1"  value="'.$head_CityName.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_Pin.'</div>
					<input type="text" id="txtpincode1_'.$membercompanyid.'" name="txtpincode1" value="'.$head_Pin.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Country.'</div>
               <select id="txtcountry" name="txtcountry" class="form-control company_text_'.$membercompanyid.'"  onChange="getState(this.value,'.$head_Stateid1.')" style="display:none;">
						<option value="">Select Country</option>
	'.$selected_country.'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_StateidName.'</div>
               <select id="txtstate" name="txtstate" class="form-control company_text_'.$membercompanyid.'"  style="display:none;">
						<option value="" >Select State</option>
						'.$variable_tocallfunction.'
					</select>
				</div>
				</div>
									</div>
										</div>
										</div>
										</div>
										<div class="col-lg-6 company-details" id="single_company_'.$membercompanyid.'">
									<div class="card">
				<div class="card-body" id="company_panel_'.$membercompanyid.'">
					<div id="form_content_company_'.$membercompanyid.'">
					
					<div class="row">
			<div class="form-group col-md-12">
					<label><b>Upload LOGO</b></label>
					<div class="company_span_'.$membercompanyid.'" id="imgupload_logo_div"><img src='.$upload_logo.' class="company_span_'.$membercompanyid.'"></div>
					<div id="uploadedimage" class="uploadedimage">
        
		</div>
		<input type="hidden" name="galleryimagename" id="galleryimagename" value="'.$upload_logo1.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;"/>
		<img src='.$upload_logo.' id="imgupload_logo"  class="form-control company_text_'.$membercompanyid.'" style="display:none;">
			<!--  <a href="#" id="fileToUpload" name="fileToUpload" >Upload Logo</a>  -->
			'.$upload_logo_var.'
				</div>
				</div>
				<div class="row">
				<div class="form-group col-md-12">
					<label><b>Upload Header For Invoice</b></label>
					<div class="company_span_'.$membercompanyid.'" id="imgupload_header_div">
							<img src='.$upload_header.' class="company_span_'.$membercompanyid.'">
					</div>
					<div id="uploadedimageforheader" class="uploadedimageforheader" >
					</div>
		<input type="hidden" name="galleryimagenameforheader" id="galleryimagenameforheader" value="'.$upload_header1.'"  class="form-control company_text_'.$membercompanyid.'" style="display:none;">
		<img src='.$upload_header.' id="imgupload_header" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
<!--	  	<a href="#" id="fileToUpload1" name="fileToUpload1">Upload Photo</a>  -->
				'.$upload_header_var.'	
				</div>
				
				</div>
				
				</div></div></div></div></div>
				
				<div class="row">
				<div class="col-lg-6 company-details" id="single_company_'.$membercompanyid.'">
				<div class="card">
				<div class="card-body" id="company_panel_'.$membercompanyid.'">
					<div id="form_content_company_'.$membercompanyid.'">
					
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Contact Person Name</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$PersonName1.'</div>
					<input type="text" id="txtclientname_'.$membercompanyid.'" name="txtclientname"  value="'.$PersonName1.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Phone Number</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_TelNo.'</div>
					<input type="text" id="txthead_TelNo_'.$membercompanyid.'" name="txthead_TelNo"  value="'.$head_TelNo.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Mobile Number </b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_mobNo.'</div>
					<input type="text" id="head_mobNo_'.$membercompanyid.'" name="head_mobNo"  value="'.$head_mobNo.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Email Address</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$head_Email.'</div>
					<input type="text" id="head_Email_'.$membercompanyid.'" name="head_Email"  value="'.$head_Email.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
				
				</div>
				</div>
				</div>
				</div>


				

				
				
				
				<div class="col-lg-6 company-details" id="single_company_'.$membercompanyid.'">
				<div class="card">
				<div class="card-body" id="company_panel_'.$membercompanyid.'">
					<div id="form_content_company_'.$membercompanyid.'">
						<div class="row">
			<div class="form-group col-md-6">
					<label><b>Active/Inactive State</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$status1.'</div>
					<select  id="input-select" name="txtstatus" class="form-control company_text_'.$membercompanyid.'"  style="display:none;">
							<option value="1"'.$valselect1.'>Active</option>
							<option value="0"'.$valselect0.'>Inactive</option>
						
							</select>
				</div>
				<div class="form-group col-md-6">
					<label><b>GST applicatble</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$gstapplicable1.'</div>
					<select  id="input-select" name="txtgstapplicable" class="form-control company_text_'.$membercompanyid.'"  style="display:none;">
							<option value="0">GST applicable/ Product</option>
							<option value="1">GST applicatble/invoice</option>
						
							</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>GST No</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$gstno.'</div>
					<input type="text" id="txtgstno1_'.$membercompanyid.'" name="txtgstno1"  value="'.$gstno.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Company PAN NO.</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$panno.'</div>
					<input type="text" id="txtpanno_'.$membercompanyid.'" name="txtpanno"  value="'.$panno.'" class="form-control company_text_'.$membercompanyid.'" onchange="ValidatePAN()" style="display:none;">
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Company TAN NO.</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Tan_No.'</div>
					<input type="text" id="txttanno_'.$membercompanyid.'" name="txttanno"  value="'.$Tan_No.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>	
					</div>
				</div>
				</div>
				</div>


				
				<div class="card">
				<h5 class="card-header"> Bank Details</h5>
				<div class="card-body" id="company_panel_'.$membercompanyid.'">
					<div id="form_content_company_'.$membercompanyid.'">
					
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Bank Name</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$BankName.'</div>
					<input type="text" id="txtbankname1'.$membercompanyid.'" name="txtbankname1"  value="'.$BankName.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
					
				</div>
				
				
				
			
				<div class="form-group col-md-6">
					<label><b>Bank A/C No.</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Bank_ACno.'</div>
					<input type="text" id="txtacno'.$membercompanyid.'" name="txtacno"  value="'.$Bank_ACno.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Branch</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$Branch.'</div>
					<input type="text" id="txtbranch'.$membercompanyid.'" name="txtbranch"  value="'.$Branch.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>IFSC Code</b></label>
					<div class="company_span_'.$membercompanyid.'">'.$IFSC_Code.'</div>
					<input type="text" id="txtIFSC'.$membercompanyid.'" name="txtIFSC"  value="'.$IFSC_Code.'" class="form-control company_text_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
				
				
				</div>
				</div>	
					</div>
				</div>
				</div>				
				
				</form>'.$editable_grid.'';																	
		}
					
					
					return $companyMenu;
					
			//}
}

/*

function ManageUserCompanyDetailsDisplayss($companyid='')
	{		
			
		
			$companyMenu1='';
			$company			=	new Company();
		
	$sqllists	=$company->getCompany("","","select * from user_company where membercompanyid = $companyid");
	//print_r($sqllist);
			//if(is_array($factorylist))
			//{
					 $rowcount			=		count($sqllists);
				for($i=0;$i<$rowcount;$i++)
	{
		$companyname 								= $sqllists[$i]['companyname'];
 	    $memberid									= $sqllists[$i]['memberid'];
		$membercompanyid1							= $sqllists[$i]['membercompanyid'];
		$Addline1									= $sqllists[$i]['Addline1'];
		$Addline2									= $sqllists[$i]['Addline2'];
		$head_CityName								= $sqllists[$i]['head_CityName'];
		$gstno 		   = $sqllists[$i]['gstno'];
		$panno 	      = $sqllists[$i]['panno'];
		$Tan_No 	      = $sqllists[$i]['Tan_No'];
		$head_TelNo	   = $sqllists[$i]['head_TelNo'];
		$head_mobNo	   = $sqllists[$i]['head_mobNo'];
		$head_FaxNo	   = $sqllists[$i]['head_FaxNo'];
		$head_Email	   = $sqllists[$i]['head_Email'];
	   $PersonName1   = $sqllists[$i]['comp_contact_personname'];
		$gstapplicable = $sqllists[$i]['gstapplicable'];
		$head_Pin      = $sqllists[$i]['head_Pin'];
	   $Country  		= $sqllists[$i]['Country'];
		$head_TelNo    = $sqllists[$i]['head_TelNo'];

		$BankName = $sqllists[$i]['Bankname'];
		$Bank_ACno      = $sqllists[$i]['BankAC'];
	   $Branch  		= $sqllists[$i]['Branch'];
		$IFSC_Code    = $sqllists[$i]['IFSC_Code'];

		$Address	 	   =	$sqllists[$i]['Addline1']."<br>".$sqllists[$i]['Addline2']."<br>".$sqllists[$i]['head_CityName']."<br>".$sqllists[$i]['head_StateidName'].'-'.$sqllists[$i]['head_Pin']."<br>".$sqllists[$i]['Country'];
		$status		   = $sqllists[$i]['memberapprovalstatus'];
		 $memberapprovalstatus					= $sqllists[$i]['memberapprovalstatus'];
		      if($memberapprovalstatus == '1')
		      {
					$valselect1      = "selected";
		      }
		      elseif($memberapprovalstatus == '0')
		      {
					$valselect0      = "selected";
		      }
		       if($status == '1') {
		      	$status1 ="Active";
		      }
		       else if($status == '0') {
		      	$status1 ="Inactive";
		      }
		       if($gstapplicable == '1') {
		      	$gstapplicable1 ="GST applicable/ invoice";
		      }
		       else if($gstapplicable == '0') {
		      	$gstapplicable1 ="GST applicable/  Product";
		      }
		      
		   $head_Stateid1								= $sqllists[$i]['head_Stateid1'];
		   $head_StateidName							= $sqllists[$i]['head_StateidName'];
			
			$selected_country 						= getAllCountryListForCombo($Country); 
	//		$selected_state  							=	getAllStateListForComboEdit($head_Stateid1);
			$upload_logo								= GALLERY_PHOTO_THUMB_PATH.$sqllists[$i]['upload_logo'];
			$upload_header								= GALLERY_PHOTO_THUMB_PATH.$sqllists[$i]['upload_header'];
			$upload_logo1								= $sqllists[$i]['upload_logo'];
			$upload_header1							= $sqllists[$i]['upload_header'];
			$variable_tocallfunction 				= getState($Country,$head_Stateid1);
	 		
							$formid1 					= 		"'company_reg_form1_".$membercompanyid1."'";
							$sendurl1					=		"'company_details_submit.php'";
							//$deleteurl				=		"'delete_company_details.php'";
							
							

								$editable_grid1 = '<a href="#" class="btn btn-space btn-light company_edit1 company_span1_'.$membercompanyid1.'" rel="'.$membercompanyid1.'" id="company_edit1_'.$membercompanyid1.'" onclick="return false;">EDITs</a>
															<a href="#" class="btn btn-space btn-primary company_cancel1 company_text1_'.$membercompanyid1.'" rel="'.$membercompanyid1.'" id="company_cancel1_'.$membercompanyid1.'" onclick="return false;" style="display:none;">CANCEL</a>
															<a href="#" class="btn btn-space btn-secondary company_save1 company_text1_'.$membercompanyid1.'" rel="'.$membercompanyid1.'" id="company_save1'.$membercompanyid1.'" onclick="formAjax('.$formid1.','.$sendurl1.'); return false;" style="display:none;">SAVE</a>
															';

	  if ($upload_logo1=="")
	  {
	  	 	$upload_logo_var = '<a href="#" id="fileToUpload" name="fileToUpload" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">Upload Logo</a>';
	  }
	  else if ($upload_logo1 !="")
	  {
	  		$upload_logo_var = '<a href="#" id="fileToUpload" name="fileToUpload" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">Change Logo</a>';
	   }
	   
	  if ($upload_header1=="")
	  {
	  	 	$upload_header_var = '<a href="#" id="fileToUpload1" name="fileToUpload1" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">Upload Header</a>';
	  }
	  else if ($upload_header1 !="")
	  {
	  		$upload_header_var = '<a href="#" id="fileToUpload1" name="fileToUpload1" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">Change Header</a> <br> 
	  									 <a href="#" id="CancelUploadedHeader" name="CancelUploadedHeader" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">Remove Header</a>';
	  }
		// &nbsp;&nbsp;&nbsp;<a href="#" id="CancelUploadedImage" name="CancelUploadedImage">Remove Logo</a>
	  
															
				$companyMenu1.=	'<form id="company_reg_form1_'.$membercompanyid1.'">
				<div class="row">
				<div class="col-lg-6 company-details1" id="single_companys_'.$membercompanyid1.'">
									<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid1.'">
					<div id="form_content_company1_'.$membercompanyid1.'">
						
								<input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
									<input type="hidden" id="txtcompanyid_'.$membercompanyid1.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtmemberid_'.$membercompanyid1.'" name="txtmemberid" value="'.$memberid.'" class="form-control">
									<input type="hidden" id="txtmembercompanyid1_'.$membercompanyid1.'" name="txtmembercompanyid1" value="'.$membercompanyid1.'" class="form-control">
									<input type="hidden" id="operation_company_'.$membercompanyid1.'" name="operation_company" value="edit_company" class="form-control">
			<!-- <div class="form-group">
					<label><b>Address : </b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Address.'</div>
					<textarea readonly id="txtaddress_'.$membercompanyid1.'" name="txtaddress" class="form-control company_text1_'.$membercompanyid1.'" rows="3" style="display:none;">'.$Address.'</textarea>
				</div>  -->
				<div class="row">
				<div class="form-group col-md-6">
					<label><b>Company Name</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$companyname.'</div>
					<input type="text" id="txtcompanyname_'.$membercompanyid1.'" name="txtcompanyname"  value="'.$companyname.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				
				</div>
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Addline1.'</div>
					<input type="text" id="txtaddressline1_'.$membercompanyid1.'" name="txtaddressline1"  value="'.$Addline1.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Addline2.'</div>
					<input type="text" id="txtaddressline2_'.$membercompanyid1.'" name="txtaddressline2"  value="'.$Addline2.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_CityName.'</div>
					<input type="text" id="txthead_CityName1_'.$membercompanyid1.'" name="txthead_CityName1"  value="'.$head_CityName.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_Pin.'</div>
					<input type="text" id="txtpincode1_'.$membercompanyid1.'" name="txtpincode1" value="'.$head_Pin.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Country.'</div>
               <select id="txtcountry" name="txtcountry" class="form-control company_text1_'.$membercompanyid1.'"  onChange="getState(this.value,'.$head_Stateid1.')" style="display:none;">
						<option value="">Select Country</option>
	'.$selected_country.'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_StateidName.'</div>
               <select id="txtstate" name="txtstate" class="form-control company_text1_'.$membercompanyid1.'"  style="display:none;">
						<option value="" >Select State</option>
						'.$variable_tocallfunction.'
					</select>
				</div>
				</div>
									</div>
										</div>
										</div>
										</div>
										<div class="col-lg-6 company-details1" id="single_companys_'.$membercompanyid1.'">
									<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid1.'">
					<div id="form_content_company1_'.$membercompanyid1.'">
					
					<div class="row">
			<div class="form-group col-md-12">
					<label><b>Upload LOGO</b></label>
					<div class="company_span1_'.$membercompanyid1.'" id="imgupload_logo_div"><img src='.$upload_logo.' class="company_span1_'.$membercompanyid1.'"></div>
					<div id="uploadedimage" class="uploadedimage">
        
		</div>
		<input type="hidden" name="galleryimagename" id="galleryimagename" value="'.$upload_logo1.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;"/>
		<img src='.$upload_logo.' id="imgupload_logo"  class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
			<!--  <a href="#" id="fileToUpload" name="fileToUpload" >Upload Logo</a>  -->
			'.$upload_logo_var.'
				</div>
				</div>
				<div class="row">
				<div class="form-group col-md-12">
					<label><b>Upload Header For Invoice</b></label>
					<div class="company_span1_'.$membercompanyid1.'" id="imgupload_header_div">
							<img src='.$upload_header.' class="company_span1_'.$membercompanyid1.'">
					</div>
					<div id="uploadedimageforheader" class="uploadedimageforheader" >
					</div>
		<input type="hidden" name="galleryimagenameforheader" id="galleryimagenameforheader" value="'.$upload_header1.'"  class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
		<img src='.$upload_header.' id="imgupload_header" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
<!--	  	<a href="#" id="fileToUpload1" name="fileToUpload1">Upload Photo</a>  -->
				'.$upload_header_var.'	
				</div>
				
				</div>
				
				</div></div></div></div></div>
				
				<div class="row">
				<div class="col-lg-6 company-details1" id="single_companys_'.$membercompanyid1.'">
				<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid1.'">
					<div id="form_content_company1_'.$membercompanyid1.'">
					
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Contact Person Name</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$PersonName1.'</div>
					<input type="text" id="txtclientname_'.$membercompanyid1.'" name="txtclientname"  value="'.$PersonName1.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Phone Number</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_TelNo.'</div>
					<input type="text" id="txthead_TelNo_'.$membercompanyid1.'" name="txthead_TelNo"  value="'.$head_TelNo.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Mobile Number </b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_mobNo.'</div>
					<input type="text" id="head_mobNo_'.$membercompanyid1.'" name="head_mobNo"  value="'.$head_mobNo.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Email Address</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$head_Email.'</div>
					<input type="text" id="head_Email_'.$membercompanyid1.'" name="head_Email"  value="'.$head_Email.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				</div>
				
				</div>
				</div>
				</div>
				</div>


				

				
				
				
				<div class="col-lg-6 company-details1" id="single_companys_'.$membercompanyid1.'">
				<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid1.'">
					<div id="form_content_company1_'.$membercompanyid1.'">
						<div class="row">
			<div class="form-group col-md-6">
					<label><b>Active/Inactive State</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$status1.'</div>
					<select  id="input-select" name="txtstatus" class="form-control company_text1_'.$membercompanyid1.'"  style="display:none;">
							<option value="1"'.$valselect1.'>Active</option>
							<option value="0"'.$valselect0.'>Inactive</option>
						
							</select>
				</div>
				<div class="form-group col-md-6">
					<label><b>GST applicatble</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$gstapplicable1.'</div>
					<select  id="input-select" name="txtgstapplicable" class="form-control company_text1_'.$membercompanyid1.'"  style="display:none;">
							<option value="0">GST applicable/ Product</option>
							<option value="1">GST applicatble/invoice</option>
						
							</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>GST No</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$gstno.'</div>
					<input type="text" id="txtgstno1_'.$membercompanyid1.'" name="txtgstno1"  value="'.$gstno.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Company PAN NO.</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$panno.'</div>
					<input type="text" id="txtpanno_'.$membercompanyid1.'" name="txtpanno"  value="'.$panno.'" class="form-control company_text1_'.$membercompanyid1.'" onchange="ValidatePAN()" style="display:none;">
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Company TAN NO.</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Tan_No.'</div>
					<input type="text" id="txttanno_'.$membercompanyid1.'" name="txttanno"  value="'.$Tan_No.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>	
					</div>
				</div>
				</div>
				</div>


				
				<div class="card">
				<h5 class="card-header"> Bank Details</h5>
				<div class="card-body" id="company_panel1_'.$membercompanyid1.'">
					<div id="form_content_company1_'.$membercompanyid1.'">
					
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Bank Name</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$BankName.'</div>
					<input type="text" id="txtbankname1'.$membercompanyid1.'" name="txtbankname1"  value="'.$BankName.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
					
				</div>
				
				
				
			
				<div class="form-group col-md-6">
					<label><b>Bank A/C No.</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Bank_ACno.'</div>
					<input type="text" id="txtacno'.$membercompanyid1.'" name="txtacno"  value="'.$Bank_ACno.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Branch</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$Branch.'</div>
					<input type="text" id="txtbranch'.$membercompanyid1.'" name="txtbranch"  value="'.$Branch.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>IFSC Code</b></label>
					<div class="company_span1_'.$membercompanyid1.'">'.$IFSC_Code.'</div>
					<input type="text" id="txtIFSC'.$membercompanyid1.'" name="txtIFSC"  value="'.$IFSC_Code.'" class="form-control company_text1_'.$membercompanyid1.'" style="display:none;">
				</div>
				</div>
				
				
				</div>
				</div>	
					</div>
				</div>
				</div>				
				
				</form>'.$editable_grid1.'';																	
		}
					
					
					return $companyMenu1;
					
			//}
}

*/


function ManageUserCompanyDetailsDisplay($companyid='')
	{		
			
		
			$companyMenus='';
			$company			=	new Company();
		
	$sqllist	=$company->getCompany("","","select * from trnuser_company a where a.membercompanyid = $companyid");
	//echo $sqllist;
	//print_r($sqllist);
			//if(is_array($factorylist))
			//{
					 $rowcount			=		count($sqllist);
				for($i=0;$i<$rowcount;$i++)
	{
		$companyname 								= $sqllist[$i]['user_companyname'];
		$MemberName 								= $sqllist[$i]['MemberName'];
		$MemberSurName 								= $sqllist[$i]['MemberSurName'];
		$password 								= $sqllist[$i]['user_password'];
		$Name=$MemberName." ".$MemberSurName;
 	    $memberid									= $sqllist[$i]['memberid'];
		$membercompanyid							= $sqllist[$i]['membercompanyid'];
		$Addline1									= $sqllist[$i]['Addline1'];
		$Addline2									= $sqllist[$i]['Addline2'];
		$dateofbirth									= $sqllist[$i]['dateofbirth'];
		$gender									= $sqllist[$i]['gender'];
		$head_CityName								= $sqllist[$i]['head_CityName'];
		
		$head_TelNo	   = $sqllist[$i]['head_TelNo'];
		$head_mobNo	   = $sqllist[$i]['head_Mob_no'];
		$head_FaxNo	   = $sqllist[$i]['head_FaxNo'];
		$head_Email	   = $sqllist[$i]['head_Email'];
	  
		$head_Pin      = $sqllist[$i]['head_Pin'];
	   $Country  		= $sqllist[$i]['Country'];
		//$head_TelNo    = $sqllist[$i]['head_TelNo'];

		$BankName = $sqllist[$i]['Bankname'];
		$Bank_ACno      = $sqllist[$i]['BankAC'];
	   $Branch  		= $sqllist[$i]['Branch'];
		$IFSC_Code    = $sqllist[$i]['IFSC_Code'];

		$Address	 	   =	$sqllist[$i]['Addline1']."<br>".$sqllist[$i]['Addline2']."<br>".$sqllist[$i]['head_CityName']."<br>".$sqllist[$i]['head_Stateid'].'-'.$sqllist[$i]['head_Pin']."<br>".$sqllist[$i]['Country'];
		$status		   = $sqllist[$i]['memberapprovalstatus'];
		 $memberapprovalstatus					= $sqllist[$i]['memberapprovalstatus'];
		      if($memberapprovalstatus == '1')
		      {
					$valselect1      = "selected";
		      }
		      elseif($memberapprovalstatus == '0')
		      {
					$valselect0      = "selected";
		      }
		
		      
		   $head_Stateid1								= $sqllist[$i]['head_Stateid'];
		   $head_StateidName							= $sqllist[$i]['head_StateName'];
			
			$selected_country 						= getAllCountryListForCombo($Country); 
	//		$selected_state  							=	getAllStateListForComboEdit($head_Stateid1);
		
			$variable_tocallfunction 				= getState($Country,$head_Stateid1);
	 		
							$formids 					= 		"'company_reg_forms1_'";
							$sendurls					=		"'manage_user_companyform_submit.php'";
							//$deleteurl				=		"'delete_company_details.php'";
							
							

								$editable_grids = '<a href="#" class="btn btn-space btn-light managecompany_edit company_spans_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="managecompany_edit_'.$membercompanyid.'" onclick="return false;">EDIT</a>
									
									<a href="#" class="btn btn-space btn-primary company_cancels company_text1_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="company_cancels_'.$membercompanyid.'" onclick="return false;" style="display:none;">CANCEL</a>
									

										 <a href="#" class="btn btn-space btn-primary claim_save company_text1_'.$membercompanyid.'" rel="'.$membercompanyid.'" id="claim_save'.$membercompanyid.'"  onclick="formAjax('.$formids.','.$sendurls.'); return false;" style="display:none;">SAVE</a>
									
															';

	 //echo $editable_grids;

		// &nbsp;&nbsp;&nbsp;<a href="#" id="CancelUploadedImage" name="CancelUploadedImage">Remove Logo</a>
	  
															
				$companyMenus.=	'<form id="company_reg_forms1_">
				<div class="row">
				<div class="col-lg-6 company-details1" id="single_company1_'.$membercompanyid.'">
									<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid.'">
					<div id="form_content_company1_'.$membercompanyid.'">
						
								<input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
									<input type="hidden" id="txtcompanyid_'.$membercompanyid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtmemberid_'.$membercompanyid.'" name="txtmemberid" value="'.$memberid.'" class="form-control">
									<input type="hidden" id="txtmembercompanyid_'.$membercompanyid.'" name="txtmembercompanyid" value="'.$membercompanyid.'" class="form-control">
									<input type="hidden" id="operation_company_'.$membercompanyid.'" name="operation_company" value="edit_company" class="form-control">
			<!-- <div class="form-group">
					<label><b>Address : </b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$Address.'</div>
					<textarea readonly id="txtaddress_'.$membercompanyid.'" name="txtaddress" class="form-control company_text1_'.$membercompanyid.'" rows="3" style="display:none;">'.$Address.'</textarea>
				</div>  -->
				<div class="row">
				<div class="form-group col-md-6">
					<label><b>Name</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$MemberName.'</div>
					<input type="text" id="txtcompanyname_'.$membercompanyid.'" name="txtcustomerName"  value="'.$MemberName.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				
				</div>
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$Addline1.'</div>
					<input type="text" id="txtaddressline1_'.$membercompanyid.'" name="txtaddressline1"  value="'.$Addline1.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$Addline2.'</div>
					<input type="text" id="txtaddressline2_'.$membercompanyid.'" name="txtaddressline2"  value="'.$Addline2.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_CityName.'</div>
					<input type="text" id="txthead_CityName1_'.$membercompanyid.'" name="txthead_CityName1"  value="'.$head_CityName.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_Pin.'</div>
					<input type="text" id="txtpincode1_'.$membercompanyid.'" name="txtpincode1" value="'.$head_Pin.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$Country.'</div>
               <select id="txtcountry" name="txtcountry" class="form-control company_text1_'.$membercompanyid.'"  onChange="getState(this.value,'.$head_Stateid1.')" style="display:none;">
						<option value="">Select Country</option>
	'.$selected_country.'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_StateidName.'</div>
               <select id="txtstate" name="txtstate" class="form-control company_text1_'.$membercompanyid.'"  style="display:none;">
						<option value="" >Select State</option>
						'.$variable_tocallfunction.'
					</select>
				</div>
				</div>
				<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>Gender</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$gender.'</div>
					<input type="text" id="txthead_CityName1_'.$membercompanyid.'" name="txtgender"  value="'.$gender.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Date Of Birth</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$dateofbirth.'</div>
					<input type="date" id="txtpincode1_'.$membercompanyid.'" name="txtDOB" value="'.$dateofbirth.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>

									</div>
										</div>
										</div>
										</div>
										<div class="col-lg-6 company-details1" id="single_company1_'.$membercompanyid.'">
									<div class="card">
				<div class="card-body" id="company_panel1_'.$membercompanyid.'">
					<div id="form_content_company1_'.$membercompanyid.'">
					
					<div class="row">
			<div class="form-group col-md-12">
				




			<div class="row">
			<div class="form-group col-md-6">
					
					<label><b>UserName (Email Address)</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_Email.'</div>
					<input type="text" id="head_Email_'.$membercompanyid.'" name="head_Email"  value="'.$head_Email.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
						<label><b>Password</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$password.'</div>
					<input type="text" id="txtpassword_'.$membercompanyid.'" name="txtpassword"  value="'.$password.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				</div>
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>Mobile Number </b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_mobNo.'</div>
					<input type="text" id="head_mobNo_'.$membercompanyid.'" name="head_mobNo"  value="'.$head_mobNo.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
				
					<label><b>Phone Number</b></label>
					<div class="company_spans_'.$membercompanyid.'">'.$head_TelNo.'</div>
					<input type="text" id="txthead_TelNo_'.$membercompanyid.'" name="txthead_TelNo"  value="'.$head_TelNo.'" class="form-control company_text1_'.$membercompanyid.'" style="display:none;">
				
				</div>
				</div>
		



				</div>
				</div>
				
				
				</div></div></div></div></div>
				
			

				

				
				
						
				
				</form>'.$editable_grids.'';																	
		}
					
					
					return $companyMenus;
					
			//}
}

//Function used for user comapny factory display in panel
function CompanyFactoryDisplay($companyid)
	{		
			//$accessid = 2;
		
			$factoryMenu='';
			$factory			=	new Factories();
 //echo $sql="Select * from member_factories where companyid=$companyid";
	$factorylist		=	$factory->getFactories("","Select * from member_factories where isdeleted=0 and companyid=$companyid");
	//print_r($factorylist);
			//if(is_array($factorylist))
			//{
					$rowcount			=		count($factorylist);
					for($i=0;$i<$rowcount;$i++)
					{
							$companyid				=		$factorylist[$i]['companyid'];
							$memberfactoryid		=		$factorylist[$i]['memberfactoryid'];
							$factoryaddress		=		$factorylist[$i]['factoryaddress'];
							$factoryaddressline1	=		$factorylist[$i]['factoryaddressline1'];
							$factoryaddressline2	=		$factorylist[$i]['factoryaddressline2'];
							$factoryaddressline3	=		$factorylist[$i]['factoryaddressline3'];
							$factoryaddressline4	=		$factorylist[$i]['factoryaddressline4'];
							$factorystreet			= 		$factorylist[$i]['factorystreet'];
							$factorycity			=		$factorylist[$i]['factorycity'];	
							$factorycountry			=		$factorylist[$i]['factorycountry'];
							$factorypincode		=		$factorylist[$i]['factorypincode'];
							//$factorystateid		= 		$factorylist[$i]['factorystateid'];							
							//$factorystate			= 		$factorylist[$i]['factorystate'];
							//$factorytelno			=		$factorylist[$i]['factorytelno'];
							//$factoryfaxno			= 		$factorylist[$i]['factoryfaxno'];
							//$factoryemail			=		$factorylist[$i]['factoryemail'];
							$factorygstno			=		$factorylist[$i]['factorygstno'];
							$factorystate			= 		$factorylist[$i]['factorystate'];
	 						$factory_Stateid1								= $factorylist[$i]['factory_Stateid1'];
							$factory_StateidName							= $factorylist[$i]['factory_StateidName'];
								
							$selected_country       =getAllCountryListForCombo($factorycountry)		;	
							$variable_tocallfunction 				= getFactoryState($factorycountry,$factory_Stateid1);
							$formid 					= 		"'fact_reg_form_".$memberfactoryid."'";
							$sendurl					=		"'company_factory_submit.php'";
							$deleteurl				=		"'delete_company_factory.php'";
							
							

								$editable_grid = '<a href="#" class="btn btn-space btn-light fact_edit fact_span_'.$memberfactoryid.'" rel="'.$memberfactoryid.'" id="fact_edit_'.$memberfactoryid.'" onclick="return false;">EDIT</a>
															<a href="#" class="btn btn-space btn-primary fact_cancel fact_text_'.$memberfactoryid.'" rel="'.$memberfactoryid.'" id="fact_cancel_'.$memberfactoryid.'" onclick="return false;" style="display:none;">CANCEL</a>
															<a href="#" class="btn btn-space btn-secondary fact_save fact_text_'.$memberfactoryid.'" rel="'.$memberfactoryid.'" id="fact_save'.$memberfactoryid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>
															<a href="#" class="btn btn-space btn-danger fact_delete fact_text_'.$memberfactoryid.'" rel="'.$memberfactoryid.'" id="fact_delete'.$memberfactoryid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>';

	
															
				$factoryMenu.=	'<div class="row" >
				<div class="col-lg-6 " id="single_factory_'.$memberfactoryid.'">
									<div class="card">
				<div class="card-body" id="factory_panel_'.$memberfactoryid.'">
					<div id="form_content_factory_'.$memberfactoryid.'">
							<form id="fact_reg_form_'.$memberfactoryid.'">
									<input type="hidden" id="txtcompanyid_'.$companyid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
									<input type="hidden" id="txtmemberfactoryid_'.$memberfactoryid.'" name="txtmemberfactoryid" value="'.$memberfactoryid.'" class="form-control">
									<input type="hidden" id="operation_'.$memberfactoryid.'" name="operation" value="edit_factory" class="form-control">
		<!--	<div class="form-group">
					<label><b>Address : </b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factoryaddress.'</div>
					<textarea readonly id="txtfactoryaddress_'.$memberfactoryid.'" name="txtfactoryaddress" class="form-control fact_text_'.$memberfactoryid.'" rows="3" style="display:none;">'.$factoryaddress.'</textarea>
				</div>  -->
			<div class="row">
				<div class="form-group col-md-6">
					<label><b>Address Line 1</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factoryaddressline1.'</div>
					<input type="text" id="txtfactoryaddressline1_'.$memberfactoryid.'" name="txtfactoryaddressline1"  value="'.$factoryaddressline1.'" class="form-control fact_text_'.$memberfactoryid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Address Line 2</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factoryaddressline2.'</div>
					<input type="text" id="txtfactoryaddressline2_'.$memberfactoryid.'" name="txtfactoryaddressline2"  value="'.$factoryaddressline2.'" class="form-control fact_text_'.$memberfactoryid.'" style="display:none;">
				</div>
			
				</div>
					<div class="row">
				
				<div class="form-group col-md-6">
					<label><b>City</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factorycity.'</div>
					<input type="text" id="txtfactorycity_'.$memberfactoryid.'" name="txtfactorycity"  value="'.$factorycity.'" class="form-control fact_text_'.$memberfactoryid.'" style="display:none;">
				</div>
				<div class="form-group col-md-6">
					<label><b>Pin Code</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factorypincode.'</div>
					<input type="text" id="txtfactorypincode_'.$memberfactoryid.'" name="txtfactorypincode" value="'.$factorypincode.'" class="form-control fact_text_'.$memberfactoryid.'" style="display:none;">
				</div>
				</div>
					<div class="row">
						<div class="form-group col-md-6">
				<label><b>Country</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factorycountry.'</div>
               <select id="txtfactorycountry_'.$memberfactoryid.'" name="txtfactorycountry" class="form-control fact_text_'.$memberfactoryid.'"  onChange="getFactoryState(this.value,'.$factory_Stateid1.','.$memberfactoryid.')" style="display:none;">
						<option value="">Select Country</option>
	'.$selected_country.'
	</select>
				</div>
				<div class="form-group col-md-6">
				<label><b>State</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factory_StateidName.'</div>
               <select id="txtfactorystate_'.$memberfactoryid.'" name="txtfactorystate" class="form-control fact_text_'.$memberfactoryid.'"  style="display:none;">
						<option value="" >Select State</option>
						'.$variable_tocallfunction.'
					</select>
				</div>
				</div>
				
				<div class="row">
			<div class="form-group col-md-6">
					<label><b>GST No</b></label>
					<div class="fact_span_'.$memberfactoryid.'">'.$factorygstno.'</div>
					<input type="text" id="txtfactorygstno_'.$memberfactoryid.'" name="txtfactorygstno"  value="'.$factorygstno.'" class="form-control fact_text_'.$memberfactoryid.'" style="display:none;">
				</div>
						
							</div>
						
													
									</form>'.$editable_grid.'
									</div>
										</div>
										</div>
										</div>
										</div>';															
		}
					
					
					return $factoryMenu;
					
			//}
}

//Function used for company branch display in panel, 
	function CompanyBranchesDisplay($companyid='')
	{		
			
			$branchMenu='';
			$branch			=	new Branches();
	
			$branchlist		=	$branch->getBranches("","Select * from member_branches where isdeleted =0 and  companyid=$companyid");
			if(is_array($branchlist))
			{
					$rowcount			=		count($branchlist);
					for($i=0;$i<$rowcount;$i++)
					{
									$companyid				=		$branchlist[$i]['companyid'];
							$memberbranchid		=		$branchlist[$i]['memberbranchid'];
							$branchaddress			=		$branchlist[$i]['branchaddress'];
							$branchaddressline1	=		$branchlist[$i]['branchaddressline1'];
							$branchaddressline2	=		$branchlist[$i]['branchaddressline2'];
							$branchaddressline3	=		$branchlist[$i]['branchaddressline3'];
							$branchaddressline4	=		$branchlist[$i]['branchaddressline4'];
							$branchstreet			= 		$branchlist[$i]['branchstreet'];
							$branchcity				=		$branchlist[$i]['branchcity'];	
							$branchpincode			=		$branchlist[$i]['branchpincode'];
						//	$branchstateid			= 		$branchlist[$i]['branchstateid'];
						//	$branchstate			= 		$branchlist[$i]['branchstate'];
						//	$branchtelno			=		$branchlist[$i]['branchtelno'];
						//$branchfaxno				= 		$branchlist[$i]['branchfaxno'];
							$branchcountry 		=		$branchlist[$i]['branchcountry'];
							$branchgstno			=		$branchlist[$i]['branchgstno'];

							$branchstate			= 		$branchlist[$i]['branchstate'];
		 					$branch_Stateid1		= 		$branchlist[$i]['branch_Stateid1'];
							$branch_StateidName	=		$branchlist[$i]['branch_StateidName'];
							$GCountry				= 	$branchlist[$i]['branchcountry'];
							$selected_country 	=	getAllCountryListForCombo($GCountry);
							$variable_tocallfunction 				= getBranchState($branchcountry,$branch_Stateid1);
							$formid 					= 		"'branch_reg_form_".$memberbranchid."'";
							$sendurl					=		"'company_branch_submit.php'";
							$deleteurl				=	"'delete_company_branch.php'";
					//print_r($branchlist);
													$editable_grid = '<a href="#" class="btn btn-space btn-light branch_edit branch_span_'.$memberbranchid.'" rel="'.$memberbranchid.'" id="branch_edit_'.$memberbranchid.'" onclick="return false;">EDIT</a>
														<a href="#" class="btn btn-space btn-primary branch_cancel branch_text_'.$memberbranchid.'" rel="'.$memberbranchid.'" id="branch_cancel_'.$memberbranchid.'" onclick="return false;" style="display:none;">CANCEL</a>
														<a href="#" class="btn btn-space btn-secondary branch_save branch_text_'.$memberbranchid.'" rel="'.$memberbranchid.'" id="branch_save_'.$memberbranchid.'" onclick="formAjax('.$formid.','.$sendurl.'); return false;" style="display:none;">SAVE</a>
														<a href="#" class="btn btn-space btn-danger branch_delete branch_text_'.$memberbranchid.'" rel="'.$memberbranchid.'" id="branch_delete_'.$memberbranchid.'" onclick="DeleteformAjax('.$formid.','.$deleteurl.'); return false;">DELETE</a>';
						
							$branchMenu				.=	'<div class="row">
																<div class="col-lg-6"  id="single_branch_'.$memberbranchid.'">	 									
																	<div class="card">
																			<div class="card-body" id="branch_panel_'.$memberbranchid.'">											
																				<div id="form_content_branch_'.$memberbranchid.'">
																				
																					<form id="branch_reg_form_'.$memberbranchid.'">
																					   <input type="hidden" id="" name="txtaccessid" value="'.$accessid.'" class="form-control">
																						<input type="hidden" id="txtcompanyid_'.$memberbranchid.'" name="txtcompanyid" value="'.$companyid.'" class="form-control">
																						<input type="hidden" id="txtmemberbranchid_'.$memberbranchid.'" name="txtmemberbranchid" value="'.$memberbranchid.'" class="form-control">
																						<input type="hidden" id="operation_branch_'.$memberbranchid.'" name="operation_branch" value="edit_branch" class="form-control">
																						<!--<div class="form-group">
																							<label><b>Address : </b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchaddress.'</div>
																							<textarea readonly id="txtbranchaddress_'.$memberbranchid.'" name="txtbranchaddress" class="form-control branch_text_'.$memberbranchid.'" rows="3" style="display:none;">'.$branchaddress.'</textarea>
																						</div>  -->
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>Address Line 1</b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchaddressline1.'</div>
																							<input type="text" id="txtbranchaddressline1_'.$memberbranchid.'" name="txtbranchaddressline1"  value="'.$branchaddressline1.'" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																						</div>
																						<div class="form-group col-md-6">
																							<label><b>Address Line 2</b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchaddressline2.'</div>
																							<input type="text" id="txtbranchaddressline2_'.$memberbranchid.'" name="txtbranchaddressline2"  value="'.$branchaddressline2.'" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																						</div>
																					</div>
																					
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>City</b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchcity.'</div>
																							<input type="text" id="txtbranchcity_'.$memberbranchid.'" name="txtbranchcity"  value="'.$branchcity.'" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																						</div>
																						<div class="form-group col-md-6">
																							<label><b>Pin Code</b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchpincode.'</div>
																							<input type="text" id="txtbranchpincode_'.$memberbranchid.'" name="txtbranchpincode" value="'.$branchpincode.'" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																						</div>
																						</div>
																						<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>Country</b></label>
																								<div class="branch_span_'.$memberbranchid.'">'.$branchcountry.'</div>
																			               <select id="txtbranchcountry_'.$memberbranchid.'" name="txtbranchcountry" class="form-control branch_text_'.$memberbranchid.'"  onChange="getBranchState(this.value,'.$branch_Stateid1.','.$memberbranchid.')" style="display:none;">
																													<option value="">Select Country</option>
																								'.$selected_country.'
																								</select>
																							</div>
																							<div class="form-group col-md-6">
																							<label><b>State</b></label>
																								<div class="branch_span_'.$memberbranchid.'">'.$branch_StateidName.'</div>
																			               <select id="txtbranchstate_'.$memberbranchid.'" name="txtbranchstate" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																									<option value="" selected>Select State</option>
																									'.$variable_tocallfunction.'
																								</select>
																							</div>
																						</div>
																					<div class="row">
																						<div class="form-group col-md-6">
																							<label><b>GST No</b></label>
																							<div class="branch_span_'.$memberbranchid.'">'.$branchgstno.'</div>
																							<input type="text" id="txtbranchgstno_'.$memberbranchid.'" name="txtbranchgstno" value="'.$branchgstno.'" class="form-control branch_text_'.$memberbranchid.'" style="display:none;">
																						</div>
																						</div>
																						</form>'.$editable_grid.'
																				
																				</div>													
																			</div>
																			</div>
																  	</div>
															</div>';
					}
					
					
					
					
			}
			return $branchMenu;
		
	}
	
function getState($countryname='',$stateid="")
{
		$all_obj    			= 	new AllTables();
		
		if($countryname != '')
		{
			$query ="SELECT * FROM mststate a 
						inner join mstcountry b on a.countryid = b.countryid 
						where b.countryname = '".$countryname."' ";
		}

			$state	         = $all_obj -> getInfo("",$query);
		
			$resultscount = count($state);
			for($i=0;$i<$resultscount;$i++)
			{
				if($stateid == $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'" selected="">'.$state[$i]["StateName"].'</option>';	
				}
				else if($stateid != $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'">'.$state[$i]["StateName"].'</option>';	
				}
			}
		//return $countryid;
	return $statelist; 
}

function getFactoryState($countryname='',$stateid="")
{
		$all_obj    			= 	new AllTables();
		
		if($countryname != '')
		{
			$query ="SELECT * FROM mststate a 
						inner join mstcountry b on a.countryid = b.countryid 
						where b.countryname = '".$countryname."' ";
		}

			$state	         = $all_obj -> getInfo("",$query);
		
			$resultscount = count($state);
			for($i=0;$i<$resultscount;$i++)
			{
				if($stateid == $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'" selected="">'.$state[$i]["StateName"].'</option>';	
				}
				else if($stateid != $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'">'.$state[$i]["StateName"].'</option>';	
				}
			}
		//return $countryid;
	return $statelist; 
}

function getBranchState($countryname='',$stateid="")
{
		$all_obj    			= 	new AllTables();
		
		if($countryname != '')
		{
			$query ="SELECT * FROM mststate a 
						inner join mstcountry b on a.countryid = b.countryid 
						where b.countryname = '".$countryname."' ";
		}

			$state	         = $all_obj -> getInfo("",$query);
		
			$resultscount = count($state);
			for($i=0;$i<$resultscount;$i++)
			{
				if($stateid == $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'" selected="">'.$state[$i]["StateName"].'</option>';	
				}
				else if($stateid != $state[$i]['StateId'])
				{
					$statelist .= '<option value="'.$state[$i]["StateId"].'-'.$state[$i]["StateName"].'">'.$state[$i]["StateName"].'</option>';	
				}
			}
		//return $countryid;
	return $statelist; 
}

function getClientContactList($companyid='')
	{
			$menu			=	new ClientContacts();
		$sql="Select * from client_contacts where clientcompanyid=$companyid and isdeleted=0";
			$menulist		=	$menu->getClientContacts('',$sql);
			//print_r($menulist);
			if(is_array($menulist))
			{
					$rowcount			=		count($menulist);
					for($i=0;$i<$rowcount;$i++)
					{
							$contact_parson_name =$menulist[$i]['contact_parson_name1'];
							$clientcontactid =$menulist[$i]['clientcontactid'];
			
 							$contact_parson				.=	'<tbody>';
							$contact_parson				.=	 '<tr id="delete_row'.$clientcontactid.'">';
							$contact_parson				.=	'<td>'.$contact_parson_name.'</td>';
							$contact_parson				.=	'<td style="text-align: center;"><a href="edit-client-contacts.php?clientcontactid='.$clientcontactid.'">Edit</a></td>';
							$contact_parson				.=	'<td style="text-align: center;"><a  class="delete_contact" opt="delete_proforma" rel="<?=$i?>" clientcontactid="'.$clientcontactid.'">Delete</a></td>';
							$contact_parson				.=	'</tr>';
							 $contact_parson				.=	'</tbody>';
							
							
					}
					
					
			}
			return $contact_parson;
	}
?>